@@ -27,21 +27,20 @@
 #include "project/dialogs/clipspeed.h"
 #include "ui_scenecutdialog_ui.h"
 
-#include <QDebug>
 #include <QUrl>
 #include <klocalizedstring.h>
 #include <KMessageBox>
 #include <mlt++/Mlt.h>
 
-// static 
-QList <ProjectClip *> FilterJob::filterClips(QList <ProjectClip *>clips, const QStringList &params)
+// static
+QList<ProjectClip *> FilterJob::filterClips(const QList<ProjectClip *> &clips, const QStringList &params)
 {
     QString condition;
     if (params.count() > 3) {
         // there is a condition for this job, for example operate only on vcodec=mpeg1video
         condition = params.at(3);
     }
-    QList <ProjectClip *> result;
+    QList<ProjectClip *> result;
     for (int i = 0; i < clips.count(); i++) {
         ProjectClip *clip = clips.at(i);
         ClipType type = clip->clipType();
@@ -58,19 +57,20 @@ QList <ProjectClip *> FilterJob::filterClips(QList <ProjectClip *>clips, const Q
     return result;
 }
 
-QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectClip*> clips, QStringList parameters)
+QHash<ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(const QList<ProjectClip *> &clips, const QStringList &parameters)
 {
-    QHash <ProjectClip *, AbstractClipJob *> jobs;
+    QHash<ProjectClip *, AbstractClipJob *> jobs;
     QStringList sources;
+    sources.reserve(clips.count());
     for (int i = 0; i < clips.count(); i++) {
         sources << clips.at(i)->url();
     }
     QString filterName = parameters.first();
     if (filterName == QLatin1String("timewarp")) {
-        QMap <QString, QString> producerParams = QMap <QString, QString> ();
-        QMap <QString, QString> filterParams = QMap <QString, QString> ();
-        QMap <QString, QString> consumerParams = QMap <QString, QString> ();
-        QMap <QString, QString> extraParams = QMap <QString, QString> ();
+        QMap<QString, QString> producerParams = QMap<QString, QString> ();
+        QMap<QString, QString> filterParams = QMap<QString, QString> ();
+        QMap<QString, QString> consumerParams = QMap<QString, QString> ();
+        QMap<QString, QString> extraParams = QMap<QString, QString> ();
         producerParams.insert(QStringLiteral("in"), QStringLiteral("0"));
         producerParams.insert(QStringLiteral("out"), QStringLiteral("-1"));
         extraParams.insert(QStringLiteral("projecttreefilter"), QStringLiteral("1"));
@@ -80,30 +80,32 @@ QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectCli
         QPointer<ClipSpeed> d = new ClipSpeed(clips.count() == 1 ? QUrl::fromLocalFile(sources.first() + QStringLiteral(".mlt")) : QUrl::fromLocalFile(sources.first()).adjusted(QUrl::RemoveFilename), multipleSelection, QApplication::activeWindow());
         if (d->exec() == QDialog::Accepted) {
             QLocale locale;
-            QString speedString = QString("timewarp:%1:").arg(locale.toString(d->speed()/100));
+            QString speedString = QStringLiteral("timewarp:%1:").arg(locale.toString(d->speed() / 100));
             QDir destFolder;
             if (multipleSelection) {
                 destFolder = QDir(d->selectedUrl().toLocalFile());
             }
-        for (int i = 0; i < clips.count(); i++) {
-            QString prodstring = speedString + sources.at(i);
-            producerParams.insert(QStringLiteral("producer"), prodstring);
-            QString destination;
-            if (multipleSelection) {
-                destination = destFolder.absoluteFilePath(QUrl::fromLocalFile(sources.at(i)).fileName() + QStringLiteral(".mlt"));
-            } else {
-                destination = d->selectedUrl().toLocalFile();
+            for (int i = 0; i < clips.count(); i++) {
+                QString prodstring = speedString + sources.at(i);
+                producerParams.insert(QStringLiteral("producer"), prodstring);
+                QString destination;
+                if (multipleSelection) {
+                    destination = destFolder.absoluteFilePath(QUrl::fromLocalFile(sources.at(i)).fileName() + QStringLiteral(".mlt"));
+                } else {
+                    destination = d->selectedUrl().toLocalFile();
+                }
+                if (QFile::exists(destination)) {
+                    if (KMessageBox::questionYesNo(QApplication::activeWindow(), i18n("File %1 already exists.\nDo you want to overwrite it?", destination)) != KMessageBox::Yes) {
+                        continue;
+                    }
+                }
+                consumerParams.insert(QStringLiteral("consumer"), QStringLiteral("xml:") + destination);
+                ProjectClip *clip = clips.at(i);
+                MeltJob *job = new MeltJob(clip->clipType(), clip->clipId(), producerParams, filterParams, consumerParams, extraParams);
+                job->description = i18n("Reverse clip");
+                job->setAddClipToProject(1);
+                jobs.insert(clip, job);
             }
-            if (QFile::exists(destination)) {
-                if (KMessageBox::questionYesNo(QApplication::activeWindow(), i18n("File %1 already exists.\nDo you want to overwrite it?", destination)) != KMessageBox::Yes) continue;
-            }
-            consumerParams.insert(QStringLiteral("consumer"), "xml:" + destination);
-            ProjectClip *clip = clips.at(i);
-            MeltJob *job = new MeltJob(clip->clipType(), clip->clipId(), producerParams, filterParams, consumerParams, extraParams);
-            job->description = i18n("Reverse clip");
-            job->setAddClipToProject(1);
-            jobs.insert(clip, job);
-        }
         }
         delete d;
         return jobs;
@@ -123,9 +125,9 @@ QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectCli
             return jobs;
         }
         // Autosplit filter
-        QMap <QString, QString> producerParams = QMap <QString, QString> ();
-        QMap <QString, QString> filterParams = QMap <QString, QString> ();
-        QMap <QString, QString> consumerParams = QMap <QString, QString> ();
+        QMap<QString, QString> producerParams = QMap<QString, QString> ();
+        QMap<QString, QString> filterParams = QMap<QString, QString> ();
+        QMap<QString, QString> consumerParams = QMap<QString, QString> ();
 
         // Producer params
         // None
@@ -147,7 +149,7 @@ QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectCli
         consumerParams.insert(QStringLiteral("top_field_first"), QStringLiteral("-1"));
 
         // Extra
-        QMap <QString, QString> extraParams;
+        QMap<QString, QString> extraParams;
         extraParams.insert(QStringLiteral("key"), QStringLiteral("shot_change_list"));
         extraParams.insert(QStringLiteral("projecttreefilter"), QStringLiteral("1"));
         QString keyword(QStringLiteral("%count"));
@@ -204,10 +206,10 @@ QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectCli
         }
         QPointer<ClipStabilize> d = new ClipStabilize(sources, filterName, out);
         if (d->exec() == QDialog::Accepted) {
-            QMap <QString, QString> producerParams = d->producerParams();
-            QMap <QString, QString> filterParams = d->filterParams();
-            QMap <QString, QString> consumerParams = d->consumerParams();
-            QMap <QString, QString> extraParams;
+            QMap<QString, QString> producerParams = d->producerParams();
+            QMap<QString, QString> filterParams = d->filterParams();
+            QMap<QString, QString> consumerParams = d->consumerParams();
+            QMap<QString, QString> extraParams;
             extraParams.insert(QStringLiteral("producer_profile"), QStringLiteral("1"));
             QString destination = d->destination();
             QUrl trffile;
@@ -215,30 +217,30 @@ QHash <ProjectClip *, AbstractClipJob *> FilterJob::prepareJob(QList <ProjectCli
                 // Set clip specific infos
 
                 // in and out
-                int in = 0;
-                int out = -1;
+                int clip_in = 0;
+                int clip_out = -1;
                 ProjectClip *clip = clips.at(i);
                 if (extraParams.contains(QStringLiteral("zoneonly"))) {
                     // Analyse clip zone only, remove in / out and replace with zone
                     QPoint zone = clip->zone();
-                    in = zone.x();
-                    out = zone.y();
+                    clip_in = zone.x();
+                    clip_out = zone.y();
                 }
-                producerParams.insert(QStringLiteral("in"), QString::number(in));
-                producerParams.insert(QStringLiteral("out"), QString::number(out));
+                producerParams.insert(QStringLiteral("in"), QString::number(clip_in));
+                producerParams.insert(QStringLiteral("out"), QString::number(clip_out));
                 producerParams.insert(QStringLiteral("producer"), sources.at(i));
 
                 // Consumer
                 QString consumerName = d->consumerParams().value(QStringLiteral("consumer"));
                 if (clips.count() == 1) {
                     // We only have one clip, destination points to the final url
-                    consumerParams.insert(QStringLiteral("consumer"), consumerName + ':' + destination);
-                    trffile = QUrl::fromLocalFile(destination + ".trf");
+                    consumerParams.insert(QStringLiteral("consumer"), consumerName + QLatin1Char(':') + destination);
+                    trffile = QUrl::fromLocalFile(destination + QStringLiteral(".trf"));
                 } else {
                     // Filter several clips, destination points to a folder
-                    QString mltfile = destination + QFileInfo(clip->url()).fileName() + ".mlt";
-                    consumerParams.insert(QStringLiteral("consumer"), consumerName + ':' + mltfile);
-                    trffile = QUrl::fromLocalFile(mltfile + ".trf");
+                    QString mltfile = destination + QFileInfo(clip->url()).fileName() + QStringLiteral(".mlt");
+                    consumerParams.insert(QStringLiteral("consumer"), consumerName + QLatin1Char(':') + mltfile);
+                    trffile = QUrl::fromLocalFile(mltfile + QStringLiteral(".trf"));
                 }
                 consumerParams.insert(QStringLiteral("real_time"), QStringLiteral("-1"));
                 // Append a 'filename' parameter for saving vidstab data
