@@ -7,7 +7,7 @@ modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License or (at your option) version 3 or any later version
 accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy 
+by the membership of KDE e.V.), which shall act as a proxy
 defined in Section 14 of version 3 of the license.
 
 This program is distributed in the hope that it will be useful,
@@ -32,22 +32,19 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "bin/bin.h"
 #include "mlt++/Mlt.h"
 
-#include <QProcess>
-#include <QDialog>
-#include <QDebug>
+#include "kdenlive_debug.h"
 #include <QtConcurrent>
 
 #include <KMessageWidget>
 #include <klocalizedstring.h>
-#include <KMessageBox>
 #include "ui_scenecutdialog_ui.h"
 
 JobManager::JobManager(Bin *bin): QObject()
-  , m_bin(bin)
-  , m_abortAllJobs(false)
+    , m_bin(bin)
+    , m_abortAllJobs(false)
 {
-    connect(this, SIGNAL(processLog(QString,int,int,QString)), this, SLOT(slotProcessLog(QString,int,int,QString)));
-    connect(this, SIGNAL(checkJobProcess()), this, SLOT(slotCheckJobProcess()));
+    connect(this, &JobManager::processLog, this, &JobManager::slotProcessLog);
+    connect(this, &JobManager::checkJobProcess, this, &JobManager::slotCheckJobProcess);
 }
 
 JobManager::~JobManager()
@@ -58,7 +55,9 @@ JobManager::~JobManager()
     }
     m_jobThreads.waitForFinished();
     m_jobThreads.clearFutures();
-    if (!m_jobList.isEmpty()) qDeleteAll(m_jobList);
+    if (!m_jobList.isEmpty()) {
+        qDeleteAll(m_jobList);
+    }
     m_jobList.clear();
 }
 
@@ -81,7 +80,7 @@ QStringList JobManager::getPendingJobs(const QString &id)
     return result;
 }
 
-void JobManager::discardJobs(const QString &id, AbstractClipJob::JOBTYPE type) 
+void JobManager::discardJobs(const QString &id, AbstractClipJob::JOBTYPE type)
 {
     QMutexLocker lock(&m_jobMutex);
     for (int i = 0; i < m_jobList.count(); ++i) {
@@ -98,7 +97,9 @@ bool JobManager::hasPendingJob(const QString &clipId, AbstractClipJob::JOBTYPE t
 {
     QMutexLocker lock(&m_jobMutex);
     for (int i = 0; i < m_jobList.count(); i++) {
-        if (m_abortAllJobs) break;
+        if (m_abortAllJobs) {
+            break;
+        }
         AbstractClipJob *job = m_jobList.at(i);
         if (job->clipId() == clipId && job->jobType == type && (job->status() == JobWaiting || job->status() == JobWorking)) {
             return true;
@@ -111,14 +112,16 @@ void JobManager::slotCheckJobProcess()
 {
     if (!m_jobThreads.futures().isEmpty()) {
         // Remove inactive threads
-        QList <QFuture<void> > futures = m_jobThreads.futures();
+        QList<QFuture<void> > futures = m_jobThreads.futures();
         m_jobThreads.clearFutures();
         for (int i = 0; i < futures.count(); ++i)
             if (!futures.at(i).isFinished()) {
                 m_jobThreads.addFuture(futures.at(i));
             }
     }
-    if (m_jobList.isEmpty()) return;
+    if (m_jobList.isEmpty()) {
+        return;
+    }
 
     m_jobMutex.lock();
     int count = 0;
@@ -134,15 +137,18 @@ void JobManager::slotCheckJobProcess()
     }
     m_jobMutex.unlock();
     emit jobCount(count);
-    if (m_jobThreads.futures().isEmpty() || m_jobThreads.futures().count() < KdenliveSettings::proxythreads()) m_jobThreads.addFuture(QtConcurrent::run(this, &JobManager::slotProcessJobs));
+    if (m_jobThreads.futures().isEmpty() || m_jobThreads.futures().count() < KdenliveSettings::proxythreads()) {
+        m_jobThreads.addFuture(QtConcurrent::run(this, &JobManager::slotProcessJobs));
+    }
 }
 
 void JobManager::updateJobCount()
 {
     int count = 0;
     for (int i = 0; i < m_jobList.count(); ++i) {
-        if (m_jobList.at(i)->status() == JobWaiting || m_jobList.at(i)->status() == JobWorking)
+        if (m_jobList.at(i)->status() == JobWaiting || m_jobList.at(i)->status() == JobWorking) {
             count ++;
+        }
     }
     // Set jobs count
     emit jobCount(count);
@@ -152,7 +158,7 @@ void JobManager::slotProcessJobs()
 {
     bool firstPass = true;
     while (!m_jobList.isEmpty() && !m_abortAllJobs) {
-        AbstractClipJob *job = NULL;
+        AbstractClipJob *job = nullptr;
         m_jobMutex.lock();
         for (int i = 0; i < m_jobList.count(); ++i) {
             if (m_jobList.at(i)->status() == JobWaiting) {
@@ -166,14 +172,14 @@ void JobManager::slotProcessJobs()
         }
         m_jobMutex.unlock();
 
-        if (job == NULL) {
+        if (job == nullptr) {
             break;
         }
         firstPass = false;
         QString destination = job->destination();
         // Check if the clip is still here
         ProjectClip *currentClip = m_bin->getBinClip(job->clipId());
-        if (currentClip == NULL) {
+        if (currentClip == nullptr) {
             job->setStatus(JobDone);
             continue;
         }
@@ -185,8 +191,9 @@ void JobManager::slotProcessJobs()
             QFileInfo file(destination);
             bool writable = false;
             if (file.exists()) {
-                if (file.isWritable())
+                if (file.isWritable()) {
                     writable = true;
+                }
             } else {
                 QDir dir = file.absoluteDir();
                 if (!dir.exists()) {
@@ -202,11 +209,11 @@ void JobManager::slotProcessJobs()
                 continue;
             }
         }
-        connect(job, SIGNAL(jobProgress(QString,int,int)), this, SIGNAL(processLog(QString,int,int)));
-        connect(job, SIGNAL(cancelRunningJob(QString,QMap<QString, QString>)), m_bin, SLOT(slotCancelRunningJob(QString,QMap<QString, QString>)));
+        connect(job, SIGNAL(jobProgress(QString, int, int)), this, SIGNAL(processLog(QString, int, int)));
+        connect(job, &AbstractClipJob::cancelRunningJob, m_bin, &Bin::slotCancelRunningJob);
 
         if (job->jobType == AbstractClipJob::MLTJOB || job->jobType == AbstractClipJob::ANALYSECLIPJOB) {
-            connect(job, SIGNAL(gotFilterJobResults(QString,int,int,stringMap,stringMap)), this, SIGNAL(gotFilterJobResults(QString,int,int,stringMap,stringMap)));
+            connect(job, SIGNAL(gotFilterJobResults(QString, int, int, stringMap, stringMap)), this, SIGNAL(gotFilterJobResults(QString, int, int, stringMap, stringMap)));
         }
         job->startJob();
         if (job->status() == JobDone) {
@@ -214,8 +221,7 @@ void JobManager::slotProcessJobs()
             //TODO: replace with more generic clip replacement framework
             if (job->jobType == AbstractClipJob::PROXYJOB) {
                 m_bin->gotProxy(job->clipId(), destination);
-            }
-            else if (job->addClipToProject() > -100) {
+            } else if (job->addClipToProject() > -100) {
                 emit addClip(destination, job->addClipToProject());
             }
         } else if (job->status() == JobCrashed || job->status() == JobAborted) {
@@ -223,12 +229,12 @@ void JobManager::slotProcessJobs()
         }
     }
     // Thread finished, cleanup & update count
-    QTimer::singleShot(200, this, SIGNAL(checkJobProcess()));
+    QTimer::singleShot(200, this, &JobManager::checkJobProcess);
 }
 
-QList <ProjectClip *> JobManager::filterClips(QList <ProjectClip *>clips, AbstractClipJob::JOBTYPE jobType, const QStringList &params)
+QList<ProjectClip *> JobManager::filterClips(const QList<ProjectClip *> &clips, AbstractClipJob::JOBTYPE jobType, const QStringList &params)
 {
-     //TODO: filter depending on clip type
+    //TODO: filter depending on clip type
     if (jobType == AbstractClipJob::TRANSCODEJOB || jobType == AbstractClipJob::CUTJOB) {
         return CutClipJob::filterClips(clips, params);
     } else if (jobType == AbstractClipJob::FILTERCLIPJOB) {
@@ -236,25 +242,25 @@ QList <ProjectClip *> JobManager::filterClips(QList <ProjectClip *>clips, Abstra
     } else if (jobType == AbstractClipJob::PROXYJOB) {
         return ProxyJob::filterClips(clips);
     }
-    return QList <ProjectClip *> ();
+    return QList<ProjectClip *> ();
 }
 
-void JobManager::prepareJobFromTimeline(ProjectClip *clip, const QMap<QString,QString>&producerParams, const QMap<QString,QString>&filterParams, const QMap<QString,QString>&consumerParams, const QMap<QString,QString>&extraParams)
+void JobManager::prepareJobFromTimeline(ProjectClip *clip, const QMap<QString, QString> &producerParams, const QMap<QString, QString> &filterParams, const QMap<QString, QString> &consumerParams, const QMap<QString, QString> &extraParams)
 {
     MeltJob *job = new MeltJob(clip->clipType(), clip->clipId(), producerParams, filterParams, consumerParams, extraParams);
-    job->description = i18n("Filter %1", extraParams.value("finalfilter"));
+    job->description = i18n("Filter %1", extraParams.value(QStringLiteral("finalfilter")));
     launchJob(clip, job);
 }
 
-void JobManager::prepareJobs(QList <ProjectClip *>clips, double fps, AbstractClipJob::JOBTYPE jobType, const QStringList params)
+void JobManager::prepareJobs(const QList<ProjectClip *> &clips, double fps, AbstractClipJob::JOBTYPE jobType, const QStringList &params)
 {
     //TODO filter clips
-    QList <ProjectClip *> matching = filterClips(clips, jobType, params);
+    QList<ProjectClip *> matching = filterClips(clips, jobType, params);
     if (matching.isEmpty()) {
         m_bin->doDisplayMessage(i18n("No valid clip to process"), KMessageWidget::Information);
         return;
     }
-    QHash <ProjectClip *, AbstractClipJob *> jobs;
+    QHash<ProjectClip *, AbstractClipJob *> jobs;
     if (jobType == AbstractClipJob::TRANSCODEJOB) {
         jobs = CutClipJob::prepareTranscodeJob(fps, matching, params);
     } else if (jobType == AbstractClipJob::CUTJOB) {
@@ -278,7 +284,6 @@ void JobManager::prepareJobs(QList <ProjectClip *>clips, double fps, AbstractCli
     }
 }
 
-
 void JobManager::launchJob(ProjectClip *clip, AbstractClipJob *job, bool runQueue)
 {
     if (job->isExclusive() && hasPendingJob(clip->clipId(), job->jobType)) {
@@ -295,14 +300,16 @@ void JobManager::launchJob(ProjectClip *clip, AbstractClipJob *job, bool runQueu
 
 void JobManager::slotDiscardClipJobs()
 {
-    QAction* act = qobject_cast<QAction *>(sender());
-    if (act == 0) {
+    QAction *act = qobject_cast<QAction *>(sender());
+    if (act == nullptr) {
         // Cannot access triggering action, something is wrong
-        qDebug()<<"// Error in job action";
+        qCDebug(KDENLIVE_LOG) << "// Error in job action";
         return;
     }
     QString id = act->data().toString();
-    if (id.isEmpty()) return;
+    if (id.isEmpty()) {
+        return;
+    }
     discardJobs(id);
 }
 
@@ -335,9 +342,9 @@ void JobManager::slotCancelJobs()
     for (int i = 0; i < m_jobList.count(); ++i) {
         DocClipBase *currentClip = m_doc->clipManager()->getClipById(m_jobList.at(i)->clipId());
         if (!currentClip) continue;
-        QMap <QString, QString> newProps = m_jobList.at(i)->cancelProperties();
+        QMap<QString, QString> newProps = m_jobList.at(i)->cancelProperties();
         if (newProps.isEmpty()) continue;
-        QMap <QString, QString> oldProps = currentClip->currentProperties(newProps);
+        QMap<QString, QString> oldProps = currentClip->currentProperties(newProps);
         //TODO
         //new EditClipCommand(this, m_jobList.at(i)->clipId(), oldProps, newProps, true, command);
     }
@@ -347,7 +354,9 @@ void JobManager::slotCancelJobs()
     }
     else delete command;
     */
-    if (!m_jobList.isEmpty()) qDeleteAll(m_jobList);
+    if (!m_jobList.isEmpty()) {
+        qDeleteAll(m_jobList);
+    }
     m_jobList.clear();
     m_abortAllJobs = false;
     emit jobCount(0);
