@@ -37,18 +37,18 @@ the Free Software Foundation, either version 3 of the License, or
 #include <QCryptographicHash>
 #include <QFileDialog>
 #include <QAction>
-#include <QDebug>
+#include "kdenlive_debug.h"
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QTimeZone>
 #include <QLocale>
 #include <KConfigGroup>
 
-ProjectManager::ProjectManager(QObject* parent) :
+ProjectManager::ProjectManager(QObject *parent) :
     QObject(parent),
-    m_project(0),
-    m_trackView(0),
-    m_progressDialog(NULL)
+    m_project(nullptr),
+    m_trackView(nullptr),
+    m_progressDialog(nullptr)
 {
     m_fileRevert = KStandardAction::revert(this, SLOT(slotRevert()), pCore->window()->actionCollection());
     m_fileRevert->setIcon(KoIconUtils::themedIcon(QStringLiteral("document-revert")));
@@ -62,14 +62,14 @@ ProjectManager::ProjectManager(QObject* parent) :
     a->setIcon(KoIconUtils::themedIcon(QStringLiteral("document-new")));
     m_recentFilesAction = KStandardAction::openRecent(this, SLOT(openFile(QUrl)), pCore->window()->actionCollection());
 
-    QAction * backupAction = new QAction(KoIconUtils::themedIcon(QStringLiteral("edit-undo")), i18n("Open Backup File"), this);
+    QAction *backupAction = new QAction(KoIconUtils::themedIcon(QStringLiteral("edit-undo")), i18n("Open Backup File"), this);
     pCore->window()->addAction(QStringLiteral("open_backup"), backupAction);
     connect(backupAction, SIGNAL(triggered(bool)), SLOT(slotOpenBackup()));
 
     m_notesPlugin = new NotesPlugin(this);
 
     m_autoSaveTimer.setSingleShot(true);
-    connect(&m_autoSaveTimer, SIGNAL(timeout()), this, SLOT(slotAutoSave()));
+    connect(&m_autoSaveTimer, &QTimer::timeout, this, &ProjectManager::slotAutoSave);
 
     // Ensure the default data folder exist
     QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
@@ -81,29 +81,26 @@ ProjectManager::~ProjectManager()
 {
     delete m_notesPlugin;
 
-    if (m_trackView) {
-        delete m_trackView;
-    }
-    if (m_project) {
-	delete m_project;
-    }
+    delete m_trackView;
+    delete m_project;
 }
 
 void ProjectManager::slotLoadOnOpen()
 {
     if (m_startUrl.isValid()) {
         openFile();
-    }
-    else if (KdenliveSettings::openlastproject()) {
+    } else if (KdenliveSettings::openlastproject()) {
         openLastFile();
+    } else {
+        newFile(false);
     }
-    else newFile(false);
 
     if (!m_loadClipsOnOpen.isEmpty() && m_project) {
-        QStringList list = m_loadClipsOnOpen.split(',');
-        QList <QUrl> urls;
-        foreach(const QString &path, list) {
-            //qDebug() << QDir::current().absoluteFilePath(path);
+        const QStringList list = m_loadClipsOnOpen.split(QLatin1Char(','));
+        QList<QUrl> urls;
+        urls.reserve(list.count());
+        for (const QString &path : list) {
+            //qCDebug(KDENLIVE_LOG) << QDir::current().absoluteFilePath(path);
             urls << QUrl::fromLocalFile(QDir::current().absoluteFilePath(path));
         }
         pCore->bin()->droppedUrls(urls);
@@ -111,7 +108,7 @@ void ProjectManager::slotLoadOnOpen()
     m_loadClipsOnOpen.clear();
 }
 
-void ProjectManager::init(const QUrl& projectUrl, const QString& clipList)
+void ProjectManager::init(const QUrl &projectUrl, const QString &clipList)
 {
     m_startUrl = projectUrl;
     m_loadClipsOnOpen = clipList;
@@ -130,11 +127,11 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
     m_fileRevert->setEnabled(false);
     QString profileName = KdenliveSettings::default_profile();
     if (profileName.isEmpty()) {
-            profileName = KdenliveSettings::current_profile();
+        profileName = KdenliveSettings::current_profile();
     }
     QString projectFolder;
-    QMap <QString, QString> documentProperties;
-    QMap <QString, QString> documentMetadata;
+    QMap<QString, QString> documentProperties;
+    QMap<QString, QString> documentMetadata;
     QPoint projectTracks(KdenliveSettings::videotracks(), KdenliveSettings::audiotracks());
     pCore->monitorManager()->resetDisplay();
     QString documentId = QString::number(QDateTime::currentMSecsSinceEpoch());
@@ -147,13 +144,13 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
         if (KdenliveSettings::customprojectfolder()) {
             projectFolder = KdenliveSettings::defaultprojectfolder();
             if (!projectFolder.endsWith(QLatin1Char('/'))) {
-                projectFolder.append(QStringLiteral("/"));
+                projectFolder.append(QLatin1Char('/'));
             }
             documentProperties.insert(QStringLiteral("storagefolder"), projectFolder + documentId);
         }
     } else {
-        QPointer<ProjectSettings> w = new ProjectSettings(NULL, QMap <QString, QString> (), QStringList(), projectTracks.x(), projectTracks.y(), KdenliveSettings::defaultprojectfolder(), false, true, pCore->window());
-        connect(w, SIGNAL(refreshProfiles()), pCore->window(), SLOT(slotRefreshProfiles()));
+        QPointer<ProjectSettings> w = new ProjectSettings(nullptr, QMap<QString, QString> (), QStringList(), projectTracks.x(), projectTracks.y(), KdenliveSettings::defaultprojectfolder(), false, true, pCore->window());
+        connect(w.data(), &ProjectSettings::refreshProfiles, pCore->window(), &MainWindow::slotRefreshProfiles);
         if (w->exec() != QDialog::Accepted) {
             delete w;
             return;
@@ -179,13 +176,13 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
         documentProperties.insert(QStringLiteral("generateimageproxy"), QString::number((int) w->generateImageProxy()));
         QString preview = w->selectedPreview();
         if (!preview.isEmpty()) {
-            documentProperties.insert(QStringLiteral("previewparameters"), preview.section(";", 0, 0));
-            documentProperties.insert(QStringLiteral("previewextension"), preview.section(";", 1, 1));
+            documentProperties.insert(QStringLiteral("previewparameters"), preview.section(QLatin1Char(';'), 0, 0));
+            documentProperties.insert(QStringLiteral("previewextension"), preview.section(QLatin1Char(';'), 1, 1));
         }
         documentProperties.insert(QStringLiteral("proxyimageminsize"), QString::number(w->proxyImageMinSize()));
         if (!projectFolder.isEmpty()) {
             if (!projectFolder.endsWith(QLatin1Char('/'))) {
-                projectFolder.append(QStringLiteral("/"));
+                projectFolder.append(QLatin1Char('/'));
             }
             documentProperties.insert(QStringLiteral("storagefolder"), projectFolder +documentId);
         }
@@ -199,14 +196,14 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
     doc->m_autosave = new KAutoSaveFile(startFile, doc);
     bool ok;
     pCore->bin()->setDocument(doc);
-    QList <QAction*> rulerActions;
+    QList<QAction *> rulerActions;
     rulerActions << pCore->window()->actionCollection()->action(QStringLiteral("set_render_timeline_zone"));
     rulerActions << pCore->window()->actionCollection()->action(QStringLiteral("unset_render_timeline_zone"));
     m_trackView = new Timeline(doc, pCore->window()->kdenliveCategoryMap.value(QStringLiteral("timeline"))->actions(), rulerActions, &ok, pCore->window());
     // Set default target tracks to upper audio / lower video tracks
     m_trackView->audioTarget = projectTracks.y() > 0 ? projectTracks.y() : -1;
     m_trackView->videoTarget = projectTracks.x() > 0 ? projectTracks.y() + 1 : -1;
-    connect(m_trackView->projectView(), SIGNAL(importPlaylistClips(ItemInfo, const QString&, QUndoCommand*)), pCore->bin(), SLOT(slotExpandUrl(ItemInfo, const QString&, QUndoCommand*)), Qt::DirectConnection);
+    connect(m_trackView->projectView(), SIGNAL(importPlaylistClips(ItemInfo, QString, QUndoCommand *)), pCore->bin(), SLOT(slotExpandUrl(ItemInfo, QString, QUndoCommand *)), Qt::DirectConnection);
 
     m_trackView->loadTimeline();
     pCore->window()->m_timelineArea->addTab(m_trackView, QIcon::fromTheme(QStringLiteral("kdenlive")), doc->description());
@@ -259,20 +256,20 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
         }
     }
     if (!quit && !qApp->isSavingSession()) {
-	m_autoSaveTimer.stop();
+        m_autoSaveTimer.stop();
         if (m_project) {
             pCore->producerQueue()->abortOperations();
             pCore->bin()->abortOperations();
-            pCore->window()->slotTimelineClipSelected(NULL, false);
-            pCore->monitorManager()->clipMonitor()->slotOpenClip(NULL);
+            pCore->window()->slotTimelineClipSelected(nullptr, false);
+            pCore->monitorManager()->clipMonitor()->slotOpenClip(nullptr);
             pCore->window()->m_effectStack->clear();
-            pCore->window()->m_effectStack->transitionConfig()->slotTransitionItemSelected(NULL, 0, QPoint(), false);
+            pCore->window()->m_effectStack->transitionConfig()->slotTransitionItemSelected(nullptr, 0, QPoint(), false);
             delete m_trackView;
-            m_trackView = NULL;
+            m_trackView = nullptr;
             delete m_project;
-            m_project = NULL;
+            m_project = nullptr;
         }
-	pCore->monitorManager()->setDocument(m_project);
+        pCore->monitorManager()->setDocument(m_project);
     }
     return true;
 }
@@ -302,7 +299,7 @@ bool ProjectManager::saveFileAs(const QString &outputFileName)
     // saved under file name
     // actual saving by KdenliveDoc::slotAutoSave() called by a timer 3 seconds after the document has been edited
     // This timer is set by KdenliveDoc::setModified()
-    if (m_project->m_autosave == NULL) {
+    if (m_project->m_autosave == nullptr) {
         // The temporary file is not opened or created until actually needed.
         // The file filename does not have to exist for KAutoSaveFile to be constructed (if it exists, it will not be touched).
         m_project->m_autosave = new KAutoSaveFile(url, this);
@@ -329,7 +326,7 @@ void ProjectManager::saveRecentFiles()
     config->sync();
 }
 
-void ProjectManager::slotSaveSelection(QString path)
+void ProjectManager::slotSaveSelection(const QString &path)
 {
     m_trackView->projectView()->exportTimelineSelection(path);
 }
@@ -339,12 +336,11 @@ bool ProjectManager::hasSelection() const
     return m_trackView->projectView()->hasSelection();
 }
 
-
 bool ProjectManager::saveFileAs()
 {
     QFileDialog fd(pCore->window());
     fd.setDirectory(m_project->url().isValid() ? m_project->url().adjusted(QUrl::RemoveFilename).toLocalFile() : KdenliveSettings::defaultprojectfolder());
-    fd.setMimeTypeFilters(QStringList()<<QStringLiteral("application/x-kdenlive"));
+    fd.setMimeTypeFilters(QStringList() << QStringLiteral("application/x-kdenlive"));
     fd.setAcceptMode(QFileDialog::AcceptSave);
     fd.setFileMode(QFileDialog::AnyFile);
     fd.setDefaultSuffix(QStringLiteral("kdenlive"));
@@ -354,7 +350,7 @@ bool ProjectManager::saveFileAs()
     QString outputFile = fd.selectedFiles().first();
 
 #if KXMLGUI_VERSION_MINOR < 23 && KXMLGUI_VERSION_MAJOR == 5
-    // Since Plasma 5.7 (release at same time as KF 5.23, 
+    // Since Plasma 5.7 (release at same time as KF 5.23,
     // the file dialog manages the overwrite check
     if (QFile::exists(outputFile)) {
         // Show the file dialog again if the user does not want to overwrite the file
@@ -367,7 +363,7 @@ bool ProjectManager::saveFileAs()
     bool ok = false;
     QDir cacheDir = m_project->getCacheDir(CacheBase, &ok);
     if (ok) {
-        QFile file(cacheDir.absoluteFilePath(QUrl::toPercentEncoding("." + outputFile)));
+        QFile file(cacheDir.absoluteFilePath(QString::fromLatin1(QUrl::toPercentEncoding(QStringLiteral(".") + outputFile))));
         file.open(QIODevice::ReadWrite | QIODevice::Text);
         file.close();
     }
@@ -378,7 +374,7 @@ bool ProjectManager::saveFile()
 {
     if (!m_project) {
         // Calling saveFile before a project was created, something is wrong
-        qDebug()<<"SaveFile called without project";
+        qCDebug(KDENLIVE_LOG) << "SaveFile called without project";
         return false;
     }
     if (m_project->url().isEmpty()) {
@@ -429,26 +425,26 @@ bool ProjectManager::checkForBackupFile(const QUrl &url)
 {
     // Check for autosave file that belong to the url we passed in.
     QList<KAutoSaveFile *> staleFiles = KAutoSaveFile::staleFiles(url);
-    KAutoSaveFile *orphanedFile = NULL;
-    // Check if we can have a lock on one of the file, 
+    KAutoSaveFile *orphanedFile = nullptr;
+    // Check if we can have a lock on one of the file,
     // meaning it is not handled by any Kdenlive instancce
     if (!staleFiles.isEmpty()) {
-        foreach(KAutoSaveFile * stale, staleFiles) {
+        foreach (KAutoSaveFile *stale, staleFiles) {
             if (stale->open(QIODevice::QIODevice::ReadWrite)) {
-                  // Found orphaned autosave file
-                  orphanedFile = stale;
-                  break;
+                // Found orphaned autosave file
+                orphanedFile = stale;
+                break;
             } else {
-              // Another Kdenlive instance is probably handling this autosave file
-              staleFiles.removeAll(stale);
-              delete stale;
-              continue;
+                // Another Kdenlive instance is probably handling this autosave file
+                staleFiles.removeAll(stale);
+                delete stale;
+                continue;
             }
         }
     }
 
     if (orphanedFile) {
-        if (KMessageBox::questionYesNo(0,
+        if (KMessageBox::questionYesNo(nullptr,
                                        i18n("Auto-saved files exist. Do you want to recover them now?"),
                                        i18n("File Recovery"),
                                        KGuiItem(i18n("Recover")), KGuiItem(i18n("Don't recover"))) == KMessageBox::Yes) {
@@ -456,7 +452,7 @@ bool ProjectManager::checkForBackupFile(const QUrl &url)
             return true;
         } else {
             // remove the stale files
-            foreach(KAutoSaveFile * stale, staleFiles) {
+            foreach (KAutoSaveFile *stale, staleFiles) {
                 stale->open(QIODevice::ReadWrite);
                 delete stale;
             }
@@ -473,7 +469,7 @@ void ProjectManager::openFile(const QUrl &url)
     QMimeType mime = db.mimeTypeForUrl(url);
     if (mime.inherits(QStringLiteral("application/x-compressed-tar"))) {
         // Opening a compressed project file, we need to process it
-        //qDebug()<<"Opening archive, processing";
+        //qCDebug(KDENLIVE_LOG)<<"Opening archive, processing";
         QPointer<ArchiveWidget> ar = new ArchiveWidget(url);
         if (ar->exec() == QDialog::Accepted) {
             openFile(QUrl::fromLocalFile(ar->extractedProjectFile()));
@@ -507,51 +503,52 @@ void ProjectManager::openFile(const QUrl &url)
         return;
     }
     pCore->window()->slotGotProgressInfo(i18n("Opening file %1", url.toLocalFile()), 100, InformationMessage);
-    doOpenFile(url, NULL);
+    doOpenFile(url, nullptr);
 }
 
 void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
 {
-    Q_ASSERT(m_project == NULL);
-    if (!pCore->window()->m_timelineArea->isEnabled()) return;
+    Q_ASSERT(m_project == nullptr);
+    if (!pCore->window()->m_timelineArea->isEnabled()) {
+        return;
+    }
     m_fileRevert->setEnabled(true);
 
     // Recreate stopmotion widget on document change
     if (pCore->window()->m_stopmotion) {
         delete pCore->window()->m_stopmotion;
-        pCore->window()->m_stopmotion = NULL;
-    }
-    if (m_progressDialog) {
-        delete m_progressDialog;
+        pCore->window()->m_stopmotion = nullptr;
     }
+    delete m_progressDialog;
     pCore->monitorManager()->resetDisplay();
     m_progressDialog = new QProgressDialog(pCore->window());
     m_progressDialog->setWindowTitle(i18n("Loading project"));
-    m_progressDialog->setCancelButton(0);
+    m_progressDialog->setCancelButton(nullptr);
     m_progressDialog->setLabelText(i18n("Loading project"));
     m_progressDialog->setMaximum(0);
     m_progressDialog->show();
     bool openBackup;
     m_notesPlugin->clear();
-    KdenliveDoc *doc = new KdenliveDoc(stale ? QUrl::fromLocalFile(stale->fileName()) : url, QString(), pCore->window()->m_commandStack, KdenliveSettings::default_profile().isEmpty() ? KdenliveSettings::current_profile() : KdenliveSettings::default_profile(), QMap <QString, QString> (), QMap <QString, QString> (), QPoint(KdenliveSettings::videotracks(), KdenliveSettings::audiotracks()), pCore->monitorManager()->projectMonitor()->render, m_notesPlugin, &openBackup, pCore->window());
-    if (stale == NULL) {
+    KdenliveDoc *doc = new KdenliveDoc(stale ? QUrl::fromLocalFile(stale->fileName()) : url, QString(), pCore->window()->m_commandStack, KdenliveSettings::default_profile().isEmpty() ? KdenliveSettings::current_profile() : KdenliveSettings::default_profile(), QMap<QString, QString> (), QMap<QString, QString> (), QPoint(KdenliveSettings::videotracks(), KdenliveSettings::audiotracks()), pCore->monitorManager()->projectMonitor()->render, m_notesPlugin, &openBackup, pCore->window());
+    if (stale == nullptr) {
         stale = new KAutoSaveFile(url, doc);
         doc->m_autosave = stale;
     } else {
         doc->m_autosave = stale;
         stale->setParent(doc);
         // if loading from an autosave of unnamed file then keep unnamed
-        if (url.fileName().contains(QStringLiteral("_untitled.kdenlive")))
+        if (url.fileName().contains(QStringLiteral("_untitled.kdenlive"))) {
             doc->setUrl(QUrl());
-        else
+        } else {
             doc->setUrl(url);
+        }
         doc->setModified(true);
         stale->setParent(doc);
     }
     m_progressDialog->setLabelText(i18n("Loading clips"));
     pCore->bin()->setDocument(doc);
 
-    QList <QAction*> rulerActions;
+    QList<QAction *> rulerActions;
     rulerActions << pCore->window()->actionCollection()->action(QStringLiteral("set_render_timeline_zone"));
     rulerActions << pCore->window()->actionCollection()->action(QStringLiteral("unset_render_timeline_zone"));
     rulerActions << pCore->window()->actionCollection()->action(QStringLiteral("clear_render_timeline_zone"));
@@ -567,7 +564,7 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
     m_trackView->videoTarget = doc->getDocumentProperty(QStringLiteral("videotargettrack"), QStringLiteral("-1")).toInt();
     m_trackView->loadTimeline();
     m_trackView->loadGuides(pCore->binController()->takeGuidesData());
-    connect(m_trackView->projectView(), SIGNAL(importPlaylistClips(ItemInfo, const QString&, QUndoCommand*)), pCore->bin(), SLOT(slotExpandUrl(ItemInfo, const QString&, QUndoCommand*)), Qt::DirectConnection);
+    connect(m_trackView->projectView(), SIGNAL(importPlaylistClips(ItemInfo, QString, QUndoCommand *)), pCore->bin(), SLOT(slotExpandUrl(ItemInfo, QString, QUndoCommand *)), Qt::DirectConnection);
     pCore->window()->connectDocument();
     bool disabled = m_project->getDocumentProperty(QStringLiteral("disabletimelineeffects")) == QLatin1String("1");
     QAction *disableEffects = pCore->window()->actionCollection()->action(QStringLiteral("disable_timeline_effects"));
@@ -584,46 +581,48 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
     if (!ok) {
         pCore->window()->m_timelineArea->setEnabled(false);
         KMessageBox::sorry(pCore->window(), i18n("Cannot open file %1.\nProject is corrupted.", url.toLocalFile()));
-        pCore->window()->slotGotProgressInfo(QString(), -1);
+        pCore->window()->slotGotProgressInfo(QString(), 100);
         newFile(false, true);
         return;
     }
     m_trackView->setDuration(m_trackView->duration());
 
-    pCore->window()->slotGotProgressInfo(QString(), -1);
+    pCore->window()->slotGotProgressInfo(QString(), 100);
     pCore->monitorManager()->projectMonitor()->adjustRulerSize(m_trackView->duration() - 1);
     if (openBackup) {
         slotOpenBackup(url);
     }
     m_lastSave.start();
     delete m_progressDialog;
-    m_progressDialog = NULL;
+    m_progressDialog = nullptr;
 }
 
 void ProjectManager::slotRevert()
 {
-    if (m_project->isModified() && KMessageBox::warningContinueCancel(pCore->window(), i18n("This will delete all changes made since you last saved your project. Are you sure you want to continue?"), i18n("Revert to last saved version")) == KMessageBox::Cancel){
+    if (m_project->isModified() && KMessageBox::warningContinueCancel(pCore->window(), i18n("This will delete all changes made since you last saved your project. Are you sure you want to continue?"), i18n("Revert to last saved version")) == KMessageBox::Cancel) {
         return;
     }
     QUrl url = m_project->url();
-    if (closeCurrentDocument(false))
-        doOpenFile(url, NULL);
+    if (closeCurrentDocument(false)) {
+        doOpenFile(url, nullptr);
+    }
 }
 
 QString ProjectManager::getMimeType(bool open)
 {
     QString mimetype = i18n("Kdenlive project (*.kdenlive)");
-    if (open) mimetype.append(";;" + i18n("Archived project (*.tar.gz)"));
+    if (open) {
+        mimetype.append(QStringLiteral(";;") + i18n("Archived project (*.tar.gz)"));
+    }
     return mimetype;
 }
 
-
-KdenliveDoc* ProjectManager::current()
+KdenliveDoc *ProjectManager::current()
 {
     return m_project;
 }
 
-void ProjectManager::slotOpenBackup(const QUrl& url)
+void ProjectManager::slotOpenBackup(const QUrl &url)
 {
     QUrl projectFile;
     QUrl projectFolder;
@@ -643,7 +642,7 @@ void ProjectManager::slotOpenBackup(const QUrl& url)
         QString requestedBackup = dia->selectedFile();
         m_project->backupLastSavedVersion(projectFile.toLocalFile());
         closeCurrentDocument(false);
-        doOpenFile(QUrl::fromLocalFile(requestedBackup), NULL);
+        doOpenFile(QUrl::fromLocalFile(requestedBackup), nullptr);
         if (m_project) {
             m_project->setUrl(projectFile);
             m_project->setModified(true);
@@ -653,26 +652,23 @@ void ProjectManager::slotOpenBackup(const QUrl& url)
     delete dia;
 }
 
-Timeline* ProjectManager::currentTimeline()
+Timeline *ProjectManager::currentTimeline()
 {
     return m_trackView;
 }
 
-
-KRecentFilesAction* ProjectManager::recentFilesAction()
+KRecentFilesAction *ProjectManager::recentFilesAction()
 {
     return m_recentFilesAction;
 }
 
-
 void ProjectManager::slotStartAutoSave()
 {
     if (m_lastSave.elapsed() > 300000) {
         // If the project was not saved in the last 5 minute, force save
         m_autoSaveTimer.stop();
         slotAutoSave();
-    }
-    else {
+    } else {
         m_autoSaveTimer.start(3000); // will trigger slotAutoSave() in 3 seconds
     }
 }
@@ -695,7 +691,7 @@ void ProjectManager::slotAutoSave()
     m_lastSave.start();
 }
 
-QString ProjectManager::projectSceneList(const QString outputFolder)
+QString ProjectManager::projectSceneList(const QString &outputFolder)
 {
     bool multitrackEnabled = m_trackView->multitrackView;
     if (multitrackEnabled) {
@@ -719,7 +715,6 @@ void ProjectManager::prepareSave()
     pCore->binController()->saveProperty(QStringLiteral("kdenlive:clipgroups"), m_project->groupsXml());
 }
 
-
 void ProjectManager::slotResetProfiles()
 {
     m_project->resetProfile();
@@ -775,23 +770,20 @@ QString ProjectManager::getDefaultProjectFormat()
 {
     // On first run, lets use an HD1080p profile with fps related to timezone country. Then, when the first video is added to a project, if it does not match our profile, propose a new default.
     QTimeZone zone;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     zone = QTimeZone::systemTimeZone();
-#else
-    zone = QTimeZone(QTimeZone::systemTimeZoneId());
-#endif
 
-    QList <int> ntscCountries;
+    QList<int> ntscCountries;
     ntscCountries << QLocale::Canada << QLocale::Chile << QLocale::CostaRica << QLocale::Cuba << QLocale::DominicanRepublic << QLocale::Ecuador;
     ntscCountries  << QLocale::Japan << QLocale::Mexico << QLocale::Nicaragua << QLocale::Panama << QLocale::Peru << QLocale::Philippines;
     ntscCountries  << QLocale::PuertoRico << QLocale::SouthKorea << QLocale::Taiwan << QLocale::UnitedStates;
     bool ntscProject = ntscCountries.contains(zone.country());
-    if (!ntscProject)
-            return QStringLiteral("atsc_1080p_25");
+    if (!ntscProject) {
+        return QStringLiteral("atsc_1080p_25");
+    }
     return QStringLiteral("atsc_1080p_2997");
 }
 
-void ProjectManager::saveZone(QStringList info, QDir dir)
+void ProjectManager::saveZone(const QStringList &info, const QDir &dir)
 {
     pCore->bin()->saveZone(info, dir);
 }
@@ -799,9 +791,9 @@ void ProjectManager::saveZone(QStringList info, QDir dir)
 void ProjectManager::moveProjectData(const QString &src, const QString &dest)
 {
     // Move tmp folder (thumbnails, timeline preview)
-    KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(src),QUrl::fromLocalFile(dest));
-    connect(copyJob, SIGNAL(result(KJob *)), this, SLOT(slotMoveFinished(KJob *)));
-    connect(copyJob, SIGNAL(percent(KJob *, unsigned long)), this, SLOT(slotMoveProgress(KJob *, unsigned long)));
+    KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dest));
+    connect(copyJob, &KJob::result, this, &ProjectManager::slotMoveFinished);
+    connect(copyJob, SIGNAL(percent(KJob *, ulong)), this, SLOT(slotMoveProgress(KJob *, ulong)));
     m_project->moveProjectData(src, dest);
 }
 
@@ -814,7 +806,7 @@ void ProjectManager::slotMoveFinished(KJob *job)
 {
     if (job->error() == 0) {
         pCore->window()->slotGotProgressInfo(QString(), 100, InformationMessage);
-        KIO::CopyJob *copyJob = static_cast<KIO::CopyJob *> (job);
+        KIO::CopyJob *copyJob = static_cast<KIO::CopyJob *>(job);
         QString newFolder = copyJob->destUrl().toLocalFile();
         // Check if project folder is inside document folder, in which case, paths will be relative
         QDir projectDir(m_project->url().toString(QUrl::RemoveFilename | QUrl::RemoveScheme));
