@@ -27,7 +27,7 @@
 #include "ui_smconfig_ui.h"
 #include "kdenlivesettings.h"
 
-#include <QDebug>
+#include "kdenlive_debug.h"
 #include <QFontDatabase>
 
 #include <KMessageBox>
@@ -43,33 +43,34 @@
 #include <QtConcurrent>
 #include <QStandardPaths>
 
-MyLabel::MyLabel(QWidget* parent) :
+MyLabel::MyLabel(QWidget *parent) :
     QLabel(parent)
 {
 }
 
-void MyLabel::setImage(const QImage& img)
+void MyLabel::setImage(const QImage &img)
 {
     m_img = img;
 }
 
 //virtual
-void MyLabel::wheelEvent(QWheelEvent* event)
+void MyLabel::wheelEvent(QWheelEvent *event)
 {
-    if (event->delta() > 0)
+    if (event->delta() > 0) {
         emit seek(true);
-    else
+    } else {
         emit seek(false);
+    }
 }
 
 //virtual
-void MyLabel::mousePressEvent(QMouseEvent*)
+void MyLabel::mousePressEvent(QMouseEvent *)
 {
     emit switchToLive();
 }
 
 //virtual
-void MyLabel::paintEvent(QPaintEvent* event)
+void MyLabel::paintEvent(QPaintEvent *event)
 {
     Q_UNUSED(event);
 
@@ -80,19 +81,21 @@ void MyLabel::paintEvent(QPaintEvent* event)
     int pictureHeight = height();
     int pictureWidth = width();
     int calculatedWidth = aspect_ratio * height();
-    if (calculatedWidth > width()) pictureHeight = width() / aspect_ratio;
-    else {
+    if (calculatedWidth > width()) {
+        pictureHeight = width() / aspect_ratio;
+    } else {
         int calculatedHeight = width() / aspect_ratio;
-        if (calculatedHeight > height()) pictureWidth = height() * aspect_ratio;
+        if (calculatedHeight > height()) {
+            pictureWidth = height() * aspect_ratio;
+        }
     }
     p.drawImage(QRect((width() - pictureWidth) / 2, (height() - pictureHeight) / 2, pictureWidth, pictureHeight), m_img, QRect(0, 0, m_img.width(), m_img.height()));
     p.end();
 }
 
-
 StopmotionMonitor::StopmotionMonitor(MonitorManager *manager, QWidget *parent) :
     AbstractMonitor(Kdenlive::StopMotionMonitor, manager, parent),
-    m_captureDevice(NULL)
+    m_captureDevice(nullptr)
 {
 }
 
@@ -120,10 +123,11 @@ Kdenlive::MonitorId StopmotionMonitor::id() const
     return Kdenlive::StopMotionMonitor;
 }
 
-
 void StopmotionMonitor::stop()
 {
-    if (m_captureDevice) m_captureDevice->stop();
+    if (m_captureDevice) {
+        m_captureDevice->stop();
+    }
     emit stopCapture();
 }
 
@@ -135,7 +139,7 @@ void StopmotionMonitor::slotPlay()
 {
 }
 
-void StopmotionMonitor::mute(bool,bool)
+void StopmotionMonitor::mute(bool, bool)
 {
 }
 
@@ -143,31 +147,31 @@ void StopmotionMonitor::slotMouseSeek(int /*eventDelta*/, int /*fast*/)
 {
 }
 
-StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectFolder, const QList<QAction *> &actions, QWidget* parent) :
+StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectFolder, const QList<QAction *> &actions, QWidget *parent) :
     QDialog(parent)
-  , Ui::Stopmotion_UI()
-  , m_projectFolder(projectFolder)
-  , m_captureDevice(NULL)
-  , m_sequenceFrame(0)
-  , m_animatedIndex(-1)
-  , m_animate(false)
-  , m_manager(manager)
-  , m_monitor(new StopmotionMonitor(manager, this))
+    , Ui::Stopmotion_UI()
+    , m_projectFolder(projectFolder)
+    , m_captureDevice(nullptr)
+    , m_sequenceFrame(0)
+    , m_animatedIndex(-1)
+    , m_animate(false)
+    , m_manager(manager)
+    , m_monitor(new StopmotionMonitor(manager, this))
 {
     //setAttribute(Qt::WA_DeleteOnClose);
     //HACK: the monitor widget is hidden, it is just used to control the capturedevice from monitormanager
     m_monitor->setHidden(true);
-    connect(m_monitor, SIGNAL(stopCapture()), this, SLOT(slotStopCapture()));
+    connect(m_monitor, &StopmotionMonitor::stopCapture, this, &StopmotionWidget::slotStopCapture);
     m_manager->appendMonitor(m_monitor);
-    QAction* analyze = new QAction(i18n("Send frames to color scopes"), this);
+    QAction *analyze = new QAction(i18n("Send frames to color scopes"), this);
     analyze->setCheckable(true);
     analyze->setChecked(KdenliveSettings::analyse_stopmotion());
-    connect(analyze, SIGNAL(triggered(bool)), this, SLOT(slotSwitchAnalyse(bool)));
+    connect(analyze, &QAction::triggered, this, &StopmotionWidget::slotSwitchAnalyse);
 
-    QAction* mirror = new QAction(i18n("Mirror display"), this);
+    QAction *mirror = new QAction(i18n("Mirror display"), this);
     mirror->setCheckable(true);
     //mirror->setChecked(KdenliveSettings::analyse_stopmotion());
-    connect(mirror, SIGNAL(triggered(bool)), this, SLOT(slotSwitchMirror(bool)));
+    connect(mirror, &QAction::triggered, this, &StopmotionWidget::slotSwitchMirror);
 
     addActions(actions);
     setupUi(this);
@@ -177,12 +181,12 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
     live_button->setIcon(QIcon::fromTheme(QStringLiteral("camera-photo")));
 
     m_captureAction = actions.at(0);
-    connect(m_captureAction, SIGNAL(triggered()), this, SLOT(slotCaptureFrame()));
+    connect(m_captureAction, &QAction::triggered, this, &StopmotionWidget::slotCaptureFrame);
     m_captureAction->setCheckable(true);
     m_captureAction->setChecked(false);
     capture_button->setDefaultAction(m_captureAction);
 
-    connect(actions.at(1), SIGNAL(triggered()), this, SLOT(slotSwitchLive()));
+    connect(actions.at(1), &QAction::triggered, this, &StopmotionWidget::slotSwitchLive);
 
     QAction *intervalCapture = new QAction(i18n("Interval capture"), this);
     intervalCapture->setIcon(QIcon::fromTheme(QStringLiteral("chronometer")));
@@ -193,28 +197,27 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
     preview_button->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
     capture_button->setEnabled(false);
 
-
     // Build config menu
-    QMenu* confMenu = new QMenu;
+    QMenu *confMenu = new QMenu;
     m_showOverlay = actions.at(2);
-    connect(m_showOverlay, SIGNAL(triggered(bool)), this, SLOT(slotShowOverlay(bool)));
+    connect(m_showOverlay, &QAction::triggered, this, &StopmotionWidget::slotShowOverlay);
     overlay_button->setDefaultAction(m_showOverlay);
     //confMenu->addAction(m_showOverlay);
 
     m_effectIndex = KdenliveSettings::stopmotioneffect();
-    QMenu* effectsMenu = new QMenu(i18n("Overlay effect"));
-    QActionGroup* effectGroup = new QActionGroup(this);
-    QAction* noEffect = new QAction(i18n("No Effect"), effectGroup);
+    QMenu *effectsMenu = new QMenu(i18n("Overlay effect"));
+    QActionGroup *effectGroup = new QActionGroup(this);
+    QAction *noEffect = new QAction(i18n("No Effect"), effectGroup);
     noEffect->setData(0);
-    QAction* contrastEffect = new QAction(i18n("Contrast"), effectGroup);
+    QAction *contrastEffect = new QAction(i18n("Contrast"), effectGroup);
     contrastEffect->setData(1);
-    QAction* edgeEffect = new QAction(i18n("Edge detect"), effectGroup);
+    QAction *edgeEffect = new QAction(i18n("Edge detect"), effectGroup);
     edgeEffect->setData(2);
-    QAction* brightEffect = new QAction(i18n("Brighten"), effectGroup);
+    QAction *brightEffect = new QAction(i18n("Brighten"), effectGroup);
     brightEffect->setData(3);
-    QAction* invertEffect = new QAction(i18n("Invert"), effectGroup);
+    QAction *invertEffect = new QAction(i18n("Invert"), effectGroup);
     invertEffect->setData(4);
-    QAction* thresEffect = new QAction(i18n("Threshold"), effectGroup);
+    QAction *thresEffect = new QAction(i18n("Threshold"), effectGroup);
     thresEffect->setData(5);
 
     effectsMenu->addAction(noEffect);
@@ -223,27 +226,27 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
     effectsMenu->addAction(brightEffect);
     effectsMenu->addAction(invertEffect);
     effectsMenu->addAction(thresEffect);
-    QList <QAction*> list = effectsMenu->actions();
+    QList<QAction *> list = effectsMenu->actions();
     for (int i = 0; i < list.count(); ++i) {
         list.at(i)->setCheckable(true);
         if (list.at(i)->data().toInt() == m_effectIndex) {
             list.at(i)->setChecked(true);
         }
     }
-    connect(effectsMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotUpdateOverlayEffect(QAction*)));
+    connect(effectsMenu, &QMenu::triggered, this, &StopmotionWidget::slotUpdateOverlayEffect);
     confMenu->addMenu(effectsMenu);
 
-    QAction* showThumbs = new QAction(QIcon::fromTheme(QStringLiteral("image-x-generic")), i18n("Show sequence thumbnails"), this);
+    QAction *showThumbs = new QAction(QIcon::fromTheme(QStringLiteral("image-x-generic")), i18n("Show sequence thumbnails"), this);
     showThumbs->setCheckable(true);
     showThumbs->setChecked(KdenliveSettings::showstopmotionthumbs());
-    connect(showThumbs, SIGNAL(triggered(bool)), this, SLOT(slotShowThumbs(bool)));
+    connect(showThumbs, &QAction::triggered, this, &StopmotionWidget::slotShowThumbs);
 
-    QAction* removeCurrent = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete current frame"), this);
+    QAction *removeCurrent = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete current frame"), this);
     removeCurrent->setShortcut(Qt::Key_Delete);
-    connect(removeCurrent, SIGNAL(triggered()), this, SLOT(slotRemoveFrame()));
+    connect(removeCurrent, &QAction::triggered, this, &StopmotionWidget::slotRemoveFrame);
 
-    QAction* conf = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure"), this);
-    connect(conf, SIGNAL(triggered()), this, SLOT(slotConfigure()));
+    QAction *conf = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure"), this);
+    connect(conf, &QAction::triggered, this, &StopmotionWidget::slotConfigure);
 
     confMenu->addAction(showThumbs);
     confMenu->addAction(removeCurrent);
@@ -276,7 +279,9 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
                     capture_device->addItem(deviceInfo.at(0), "v4l");
                     capture_device->setItemData(capture_device->count() - 1, path, Qt::UserRole + 1);
                     capture_device->setItemData(capture_device->count() - 1, deviceInfo.at(1), Qt::UserRole + 2);
-                    if (path == KdenliveSettings::video4vdevice()) capture_device->setCurrentIndex(capture_device->count() - 1);
+                    if (path == KdenliveSettings::video4vdevice()) {
+                        capture_device->setCurrentIndex(capture_device->count() - 1);
+                    }
                 }
             }
         }
@@ -290,21 +295,20 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
     } else live_button->setEnabled(false);*/
 
     m_frame_preview = new MyLabel(this);
-    connect(m_frame_preview, SIGNAL(seek(bool)), this, SLOT(slotSeekFrame(bool)));
-    connect(m_frame_preview, SIGNAL(switchToLive()), this, SLOT(slotSwitchLive()));
+    connect(m_frame_preview, &MyLabel::seek, this, &StopmotionWidget::slotSeekFrame);
+    connect(m_frame_preview, &MyLabel::switchToLive, this, &StopmotionWidget::slotSwitchLive);
     layout->addWidget(m_frame_preview);
     m_frame_preview->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     video_preview->setLayout(layout);
 
-    ////qDebug()<<video_preview->winId();
+    ////qCDebug(KDENLIVE_LOG)<<video_preview->winId();
 
     QString profilePath;
     // Create MLT producer data
     if (capture_device->itemData(capture_device->currentIndex()) == "v4l") {
         // Capture using a video4linux device
-        profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/profiles/video4linux";
-    }
-    else {
+        profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/profiles/video4linux");
+    } else {
         // Decklink capture
         profilePath = KdenliveSettings::current_profile();
     }
@@ -318,19 +322,19 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
 
     live_button->setChecked(false);
     button_addsequence->setEnabled(false);
-    connect(live_button, SIGNAL(toggled(bool)), this, SLOT(slotLive(bool)));
-    connect(button_addsequence, SIGNAL(clicked(bool)), this, SLOT(slotAddSequence()));
-    connect(preview_button, SIGNAL(clicked(bool)), this, SLOT(slotPlayPreview(bool)));
-    connect(frame_list, SIGNAL(currentRowChanged(int)), this, SLOT(slotShowSelectedFrame()));
-    connect(frame_list, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(slotShowSelectedFrame()));
-    connect(this, SIGNAL(doCreateThumbs(QImage,int)), this, SLOT(slotCreateThumbs(QImage,int)));
+    connect(live_button, &QAbstractButton::toggled, this, &StopmotionWidget::slotLive);
+    connect(button_addsequence, &QAbstractButton::clicked, this, &StopmotionWidget::slotAddSequence);
+    connect(preview_button, &QAbstractButton::clicked, this, &StopmotionWidget::slotPlayPreview);
+    connect(frame_list, &QListWidget::currentRowChanged, this, &StopmotionWidget::slotShowSelectedFrame);
+    connect(frame_list, &QListWidget::itemClicked, this, &StopmotionWidget::slotShowSelectedFrame);
+    connect(this, &StopmotionWidget::doCreateThumbs, this, &StopmotionWidget::slotCreateThumbs);
 
     frame_list->addAction(removeCurrent);
     frame_list->setContextMenuPolicy(Qt::ActionsContextMenu);
     frame_list->setHidden(!KdenliveSettings::showstopmotionthumbs());
     parseExistingSequences();
     QTimer::singleShot(500, this, SLOT(slotLive()));
-    connect(&m_intervalTimer, SIGNAL(timeout()), this, SLOT(slotCaptureFrame()));
+    connect(&m_intervalTimer, &QTimer::timeout, this, &StopmotionWidget::slotCaptureFrame);
     m_intervalTimer.setSingleShot(true);
     m_intervalTimer.setInterval(KdenliveSettings::captureinterval() * 1000);
 }
@@ -341,21 +345,22 @@ StopmotionWidget::~StopmotionWidget()
     if (m_captureDevice) {
         m_captureDevice->stop();
         delete m_captureDevice;
-        m_captureDevice = NULL;
+        m_captureDevice = nullptr;
     }
 
     delete m_monitor;
 }
 
-void StopmotionWidget::slotUpdateOverlayEffect(QAction* act)
+void StopmotionWidget::slotUpdateOverlayEffect(QAction *act)
 {
-    if (act)
+    if (act) {
         m_effectIndex = act->data().toInt();
+    }
     KdenliveSettings::setStopmotioneffect(m_effectIndex);
     slotUpdateOverlay();
 }
 
-void StopmotionWidget::closeEvent(QCloseEvent* e)
+void StopmotionWidget::closeEvent(QCloseEvent *e)
 {
     slotLive(false);
     QDialog::closeEvent(e);
@@ -371,7 +376,7 @@ void StopmotionWidget::slotConfigure()
     ui.sm_interval->setSuffix(ki18np(" second", " seconds"));
     ui.sm_notifytime->setSuffix(ki18np(" second", " seconds"));
     ui.sm_notifytime->setValue(KdenliveSettings::sm_notifytime());
-    connect(ui.sm_prenotify, SIGNAL(toggled(bool)), ui.sm_notifytime, SLOT(setEnabled(bool)));
+    connect(ui.sm_prenotify, &QAbstractButton::toggled, ui.sm_notifytime, &QWidget::setEnabled);
     ui.sm_prenotify->setChecked(KdenliveSettings::sm_prenotify());
     ui.sm_loop->setChecked(KdenliveSettings::sm_loop());
     ui.sm_framesplayback->setValue(KdenliveSettings::sm_framesplayback());
@@ -399,7 +404,6 @@ void StopmotionWidget::slotShowThumbs(bool show)
     frame_list->setHidden(!show);
 }
 
-
 void StopmotionWidget::slotUpdateDeviceHandler()
 {
     slotLive(false);
@@ -411,19 +415,19 @@ void StopmotionWidget::slotUpdateDeviceHandler()
     }
     m_layout->removeWidget(m_frame_preview);
     if (data == "v4l") {
-#ifdef USE_V4L
+    #ifdef USE_V4L
         m_bmCapture = new V4lCaptureHandler(m_layout);
         m_bmCapture->setDevice(capture_device->itemData(capture_device->currentIndex(), Qt::UserRole + 1).toString(), capture_device->itemData(capture_device->currentIndex(), Qt::UserRole + 2).toString());
-#endif
+    #endif
     } else {
         m_bmCapture = new BmdCaptureHandler(m_layout);
         if (m_bmCapture) connect(m_bmCapture, SIGNAL(gotMessage(QString)), this, SLOT(slotGotHDMIMessage(QString)));
     }
-    live_button->setEnabled(m_bmCapture != NULL);
+    live_button->setEnabled(m_bmCapture != nullptr);
     m_layout->addWidget(m_frame_preview);*/
 }
 
-void StopmotionWidget::slotGotHDMIMessage(const QString& message)
+void StopmotionWidget::slotGotHDMIMessage(const QString &message)
 {
     log_box->insertItem(0, message);
 }
@@ -437,9 +441,9 @@ void StopmotionWidget::parseExistingSequences()
     filters << QStringLiteral("*_0000.png");
     //dir.setNameFilters(filters);
     QStringList sequences = dir.entryList(filters, QDir::Files, QDir::Name);
-    ////qDebug()<<"PF: "<<<<", sm: "<<sequences;
-    foreach(const QString &sequencename, sequences) {
-        sequence_name->addItem(sequencename.section('_', 0, -2));
+    ////qCDebug(KDENLIVE_LOG)<<"PF: "<<<<", sm: "<<sequences;
+    foreach (const QString &sequencename, sequences) {
+        sequence_name->addItem(sequencename.section(QLatin1Char('_'), 0, -2));
     }
 }
 
@@ -469,13 +473,12 @@ void StopmotionWidget::slotLive(bool isOn)
         // Create MLT producer data
         if (capture_device->itemData(capture_device->currentIndex()) == "v4l") {
             // Capture using a video4linux device
-            profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/profiles/video4linux";
+            profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/profiles/video4linux");
             profile = ProfilesDialog::getVideoProfile(profilePath);
             service = QStringLiteral("avformat-novalidate");
             QString devicePath = capture_device->itemData(capture_device->currentIndex(), Qt::UserRole + 1).toString();
             resource = QStringLiteral("video4linux2:%1?width:%2&amp;height:%3&amp;frame_rate:%4").arg(devicePath).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den);
-        }
-        else {
+        } else {
             // Decklink capture
             profilePath = KdenliveSettings::current_profile();
             profile = ProfilesDialog::getVideoProfile(profilePath);
@@ -483,17 +486,17 @@ void StopmotionWidget::slotLive(bool isOn)
             resource = capture_device->itemData(capture_device->currentIndex(), Qt::UserRole + 1).toString();
         }
 
-        if (m_captureDevice == NULL) {
+        if (m_captureDevice == nullptr) {
             /*TODO:
             //m_captureDevice = new MltDeviceCapture(profilePath, m_monitor->videoSurface, this);
             m_captureDevice->sendFrameForAnalysis = KdenliveSettings::analyse_stopmotion();
             m_monitor->setRender(m_captureDevice);
             connect(m_captureDevice, SIGNAL(frameSaved(QString)), this, SLOT(slotNewThumb(QString)));
-        }
+            }
 
-        m_manager->activateMonitor(Kdenlive::StopMotionMonitor);
-        QString producer = createProducer(profile, service, resource);
-        if (m_captureDevice->slotStartPreview(producer, true)) {
+            m_manager->activateMonitor(Kdenlive::StopMotionMonitor);
+            QString producer = createProducer(profile, service, resource);
+            if (m_captureDevice->slotStartPreview(producer, true)) {
             if (m_showOverlay->isChecked()) {
                 reloadOverlay();
                 slotUpdateOverlay();
@@ -502,15 +505,14 @@ void StopmotionWidget::slotLive(bool isOn)
             live_button->setChecked(true);
             log_box->insertItem(-1, i18n("Playing %1x%2 (%3 fps)", profile.width, profile.height, locale.toString((double)profile.frame_rate_num/profile.frame_rate_den).rightJustified(2, '0')));
             log_box->setCurrentIndex(0);
-        }
-        else {
-            //qDebug()<<"// problem starting stopmo";
+            }
+            else {
+            //qCDebug(KDENLIVE_LOG)<<"// problem starting stopmo";
             log_box->insertItem(-1, i18n("Failed to start device"));
             log_box->setCurrentIndex(0);
             */
         }
-    }
-    else {
+    } else {
         m_frame_preview->setHidden(false);
         live_button->setChecked(false);
         if (m_captureDevice) {
@@ -518,7 +520,7 @@ void StopmotionWidget::slotLive(bool isOn)
             log_box->insertItem(-1, i18n("Stopped"));
             log_box->setCurrentIndex(0);
             //delete m_captureDevice;
-            //m_captureDevice = NULL;
+            //m_captureDevice = nullptr;
         }
     }
 
@@ -544,10 +546,11 @@ void StopmotionWidget::slotShowOverlay(bool isOn)
         // Overlay last frame of the sequence
         reloadOverlay();
         slotUpdateOverlay();
-    }
-    else {
+    } else {
         // Remove overlay
-        if (m_captureDevice) m_captureDevice->setOverlay(QString());
+        if (m_captureDevice) {
+            m_captureDevice->setOverlay(QString());
+        }
     }
 }
 
@@ -559,12 +562,16 @@ void StopmotionWidget::reloadOverlay()
         log_box->setCurrentIndex(0);
         return;
     }
-    if (m_captureDevice) m_captureDevice->setOverlay(path);
+    if (m_captureDevice) {
+        m_captureDevice->setOverlay(path);
+    }
 }
 
 void StopmotionWidget::slotUpdateOverlay()
 {
-    if (m_captureDevice == NULL) return;
+    if (m_captureDevice == nullptr) {
+        return;
+    }
 
     QString tag;
     QStringList params;
@@ -596,10 +603,10 @@ void StopmotionWidget::slotUpdateOverlay()
     m_captureDevice->setOverlayEffect(tag, params);
 }
 
-void StopmotionWidget::sequenceNameChanged(const QString& name)
+void StopmotionWidget::sequenceNameChanged(const QString &name)
 {
     // Get rid of frames from previous sequence
-    disconnect(this, SIGNAL(doCreateThumbs(QImage,int)), this, SLOT(slotCreateThumbs(QImage,int)));
+    disconnect(this, &StopmotionWidget::doCreateThumbs, this, &StopmotionWidget::slotCreateThumbs);
     m_filesList.clear();
     m_future.waitForFinished();
     frame_list->clear();
@@ -607,16 +614,15 @@ void StopmotionWidget::sequenceNameChanged(const QString& name)
         button_addsequence->setEnabled(false);
     } else {
         // Check if we are editing an existing sequence
-        QString pattern = SlideshowClip::selectedPath(QUrl::fromLocalFile(getPathForFrame(0, sequence_name->currentText())), false, QString(), &m_filesList);
         m_sequenceFrame = m_filesList.isEmpty() ? 0 : SlideshowClip::getFrameNumberFromPath(QUrl::fromLocalFile(m_filesList.last())) + 1;
         if (!m_filesList.isEmpty()) {
             m_sequenceName = sequence_name->currentText();
-            connect(this, SIGNAL(doCreateThumbs(QImage,int)), this, SLOT(slotCreateThumbs(QImage,int)));
+            connect(this, &StopmotionWidget::doCreateThumbs, this, &StopmotionWidget::slotCreateThumbs);
             m_future = QtConcurrent::run(this, &StopmotionWidget::slotPrepareThumbs);
             button_addsequence->setEnabled(true);
         } else {
             // new sequence
-            connect(this, SIGNAL(doCreateThumbs(QImage,int)), this, SLOT(slotCreateThumbs(QImage,int)));
+            connect(this, &StopmotionWidget::doCreateThumbs, this, &StopmotionWidget::slotCreateThumbs);
             button_addsequence->setEnabled(false);
         }
         capture_button->setEnabled(live_button->isChecked());
@@ -625,7 +631,9 @@ void StopmotionWidget::sequenceNameChanged(const QString& name)
 
 void StopmotionWidget::slotCaptureFrame()
 {
-    if (m_captureDevice == NULL) return;
+    if (m_captureDevice == nullptr) {
+        return;
+    }
     if (sequence_name->currentText().isEmpty()) {
         QString seqName = QInputDialog::getText(this, i18n("Create New Sequence"), i18n("Enter sequence name"));
         if (seqName.isEmpty()) {
@@ -652,33 +660,42 @@ void StopmotionWidget::slotCaptureFrame()
     m_sequenceFrame++;
     button_addsequence->setEnabled(true);
     if (capture_interval->isChecked()) {
-        if (KdenliveSettings::sm_prenotify())
-            QTimer::singleShot((KdenliveSettings::captureinterval() - KdenliveSettings::sm_notifytime()) * 1000, this, SLOT(slotPreNotify()));
+        if (KdenliveSettings::sm_prenotify()) {
+            QTimer::singleShot((KdenliveSettings::captureinterval() - KdenliveSettings::sm_notifytime()) * 1000, this, &StopmotionWidget::slotPreNotify);
+        }
         m_intervalTimer.start();
-    }
-    else
+    } else {
         m_captureAction->setChecked(false);
+    }
 }
 
 void StopmotionWidget::slotPreNotify()
 {
-    if (m_captureAction->isChecked()) KNotification::event(QStringLiteral("ReadyToCapture"), i18n("Going to Capture Frame"), QPixmap(), this);
+    if (m_captureAction->isChecked()) {
+        KNotification::event(QStringLiteral("ReadyToCapture"), i18n("Going to Capture Frame"), QPixmap(), this);
+    }
 }
 
-
 void StopmotionWidget::slotNewThumb(const QString &path)
 {
-    if (!KdenliveSettings::showstopmotionthumbs()) return;
+    if (!KdenliveSettings::showstopmotionthumbs()) {
+        return;
+    }
     m_filesList.append(path);
-    if (m_showOverlay->isChecked()) reloadOverlay();
-    if (!m_future.isRunning()) m_future = QtConcurrent::run(this, &StopmotionWidget::slotPrepareThumbs);
+    if (m_showOverlay->isChecked()) {
+        reloadOverlay();
+    }
+    if (!m_future.isRunning()) {
+        m_future = QtConcurrent::run(this, &StopmotionWidget::slotPrepareThumbs);
+    }
 
 }
 
 void StopmotionWidget::slotPrepareThumbs()
 {
-    if (m_filesList.isEmpty())
+    if (m_filesList.isEmpty()) {
         return;
+    }
     QString path = m_filesList.takeFirst();
     emit doCreateThumbs(QImage(path), SlideshowClip::getFrameNumberFromPath(QUrl::fromLocalFile(path)));
 
@@ -702,7 +719,7 @@ void StopmotionWidget::slotCreateThumbs(const QImage &img, int ix)
     p.drawText(QPoint(3, finfo.pixelSize() + 3), nb);
     p.end();
     QIcon icon(pix);
-    QListWidgetItem* item = new QListWidgetItem(icon, QString(), frame_list);
+    QListWidgetItem *item = new QListWidgetItem(icon, QString(), frame_list);
     item->setToolTip(getPathForFrame(ix, sequence_name->currentText()));
     item->setData(Qt::UserRole, ix);
     frame_list->blockSignals(true);
@@ -713,12 +730,13 @@ void StopmotionWidget::slotCreateThumbs(const QImage &img, int ix)
 
 QString StopmotionWidget::getPathForFrame(int ix, QString seqName)
 {
-    if (seqName.isEmpty())
+    if (seqName.isEmpty()) {
         seqName = m_sequenceName;
+    }
     return m_projectFolder.toLocalFile() + QDir::separator() + seqName + QLatin1Char('_') + QString::number(ix).rightJustified(4, '0', false) + QStringLiteral(".png");
 }
 
-void StopmotionWidget::slotShowFrame(const QString& path)
+void StopmotionWidget::slotShowFrame(const QString &path)
 {
     //slotLive(false);
     QImage img(path);
@@ -733,9 +751,9 @@ void StopmotionWidget::slotShowFrame(const QString& path)
 
 void StopmotionWidget::slotShowSelectedFrame()
 {
-    QListWidgetItem* item = frame_list->currentItem();
+    QListWidgetItem *item = frame_list->currentItem();
     if (item) {
-        //int ix = item->data(Qt::UserRole).toInt();;
+        //int ix = item->data(Qt::UserRole).toInt();
         slotShowFrame(item->toolTip());
     }
 }
@@ -754,9 +772,12 @@ void StopmotionWidget::slotPlayPreview(bool animate)
         return;
     }
     if (KdenliveSettings::showstopmotionthumbs()) {
-        if (KdenliveSettings::sm_framesplayback() == 0) frame_list->setCurrentRow(0);
-        else frame_list->setCurrentRow(frame_list->count() - KdenliveSettings::sm_framesplayback());
-        QTimer::singleShot(200, this, SLOT(slotAnimate()));
+        if (KdenliveSettings::sm_framesplayback() == 0) {
+            frame_list->setCurrentRow(0);
+        } else {
+            frame_list->setCurrentRow(frame_list->count() - KdenliveSettings::sm_framesplayback());
+        }
+        QTimer::singleShot(200, this, &StopmotionWidget::slotAnimate);
     } else {
         SlideshowClip::selectedPath(QUrl::fromLocalFile(getPathForFrame(0, sequence_name->currentText())), false, QString(), &m_animationList);
         if (KdenliveSettings::sm_framesplayback() > 0) {
@@ -777,25 +798,29 @@ void StopmotionWidget::slotAnimate()
             int newRow = frame_list->currentRow() + 1;
             if (KdenliveSettings::sm_loop() || newRow < frame_list->count()) {
                 if (newRow >= frame_list->count()) {
-                    if (KdenliveSettings::sm_framesplayback() == 0) newRow = 0;
-                    else {
+                    if (KdenliveSettings::sm_framesplayback() == 0) {
+                        newRow = 0;
+                    } else {
                         // seek to correct frame
                         newRow = frame_list->count() - KdenliveSettings::sm_framesplayback();
                     }
                 }
                 frame_list->setCurrentRow(newRow);
-                QTimer::singleShot(100, this, SLOT(slotAnimate()));
+                QTimer::singleShot(100, this, &StopmotionWidget::slotAnimate);
                 return;
             }
         } else {
             if (m_animatedIndex >= m_animationList.count()) {
-                if (KdenliveSettings::sm_loop()) m_animatedIndex = 0;
-                else m_animatedIndex = -1;
+                if (KdenliveSettings::sm_loop()) {
+                    m_animatedIndex = 0;
+                } else {
+                    m_animatedIndex = -1;
+                }
             }
             if (m_animatedIndex > -1) {
                 slotShowFrame(m_animationList.at(m_animatedIndex));
                 m_animatedIndex++;
-                QTimer::singleShot(100, this, SLOT(slotAnimate()));
+                QTimer::singleShot(100, this, &StopmotionWidget::slotAnimate);
                 return;
             }
         }
@@ -809,25 +834,34 @@ void StopmotionWidget::slotSeekFrame(bool forward)
 {
     int ix = frame_list->currentRow();
     if (forward) {
-        if (ix < frame_list->count() - 1) frame_list->setCurrentRow(ix + 1);
-    } else if (ix > 0) frame_list->setCurrentRow(ix - 1);
+        if (ix < frame_list->count() - 1) {
+            frame_list->setCurrentRow(ix + 1);
+        }
+    } else if (ix > 0) {
+        frame_list->setCurrentRow(ix - 1);
+    }
 }
 
 void StopmotionWidget::slotRemoveFrame()
 {
-    if (frame_list->currentItem() == NULL) return;
-    QString path = frame_list->currentItem()->toolTip();
-    if (KMessageBox::questionYesNo(this, i18n("Delete frame %1 from disk?", path), i18n("Delete Frame")) != KMessageBox::Yes)
+    if (frame_list->currentItem() == nullptr) {
         return;
+    }
+    QString path = frame_list->currentItem()->toolTip();
+    if (KMessageBox::questionYesNo(this, i18n("Delete frame %1 from disk?", path), i18n("Delete Frame")) != KMessageBox::Yes) {
+        return;
+    }
 
     QFile f(path);
     if (f.remove()) {
-        QListWidgetItem* item = frame_list->takeItem(frame_list->currentRow());
+        QListWidgetItem *item = frame_list->takeItem(frame_list->currentRow());
         int ix = item->data(Qt::UserRole).toInt();
         if (ix == m_sequenceFrame - 1) {
             // We are removing the last frame, update counter
-            QListWidgetItem* item2 = frame_list->item(frame_list->count() - 1);
-            if (item2) m_sequenceFrame = item2->data(Qt::UserRole).toInt() + 1;
+            QListWidgetItem *item2 = frame_list->item(frame_list->count() - 1);
+            if (item2) {
+                m_sequenceFrame = item2->data(Qt::UserRole).toInt() + 1;
+            }
         }
         delete item;
     }
@@ -836,36 +870,37 @@ void StopmotionWidget::slotRemoveFrame()
 void StopmotionWidget::slotSwitchAnalyse(bool isOn)
 {
     KdenliveSettings::setAnalyse_stopmotion(isOn);
-    if (m_captureDevice) m_captureDevice->sendFrameForAnalysis = isOn;
+    if (m_captureDevice) {
+        m_captureDevice->sendFrameForAnalysis = isOn;
+    }
 }
 
 void StopmotionWidget::slotSwitchMirror(bool isOn)
 {
     //KdenliveSettings::setAnalyse_stopmotion(isOn);
-    if (m_captureDevice)
+    if (m_captureDevice) {
         m_captureDevice->mirror(isOn);
+    }
 }
 
-
 const QString StopmotionWidget::createProducer(const MltVideoProfile &profile, const QString &service, const QString &resource)
 {
     Q_UNUSED(profile)
 
-    QString playlist = "<mlt title=\"capture\"><producer id=\"producer0\" in=\"0\" out=\"99999\"><property name=\"mlt_type\">producer</property><property name=\"length\">100000</property><property name=\"eof\">pause</property><property name=\"resource\">" + resource + "</property><property name=\"mlt_service\">" + service + "</property></producer>";
+    QString playlist = QStringLiteral("<mlt title=\"capture\"><producer id=\"producer0\" in=\"0\" out=\"99999\"><property name=\"mlt_type\">producer</property><property name=\"length\">100000</property><property name=\"eof\">pause</property><property name=\"resource\">")
+            + resource + QStringLiteral("</property><property name=\"mlt_service\">") + service + QStringLiteral("</property></producer>");
 
     // overlay track
-    playlist.append("<playlist id=\"playlist0\"></playlist>");
+    playlist.append(QStringLiteral("<playlist id=\"playlist0\"></playlist>"));
 
     // video4linux track
-    playlist.append("<playlist id=\"playlist1\"><entry producer=\"producer0\" in=\"0\" out=\"99999\"/></playlist>");
-
-    playlist.append("<tractor id=\"tractor0\" title=\"video0\" global_feed=\"1\" in=\"0\" out=\"99999\">");
-    playlist.append("<track producer=\"playlist0\"/>");
-    playlist.append("<track producer=\"playlist1\"/>");
-    playlist.append("</tractor></mlt>");
+    playlist.append(QStringLiteral("<playlist id=\"playlist1\"><entry producer=\"producer0\" in=\"0\" out=\"99999\"/></playlist>"));
 
+    playlist.append(QStringLiteral("<tractor id=\"tractor0\" title=\"video0\" global_feed=\"1\" in=\"0\" out=\"99999\">"));
+    playlist.append(QStringLiteral("<track producer=\"playlist0\"/>"));
+    playlist.append(QStringLiteral("<track producer=\"playlist1\"/>"));
+    playlist.append(QStringLiteral("</tractor></mlt>"));
 
     return playlist;
 }
 
-
