@@ -17,7 +17,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-
 #include "transitionhandler.h"
 #include "mltcontroller/effectscontroller.h"
 #include "mainwindow.h"
@@ -28,32 +27,42 @@ TransitionHandler::TransitionHandler(Mlt::Tractor *tractor) : QObject()
 {
 }
 
-bool TransitionHandler::addTransition(QString tag, int a_track, int b_track, GenTime in, GenTime out, QDomElement xml)
+bool TransitionHandler::addTransition(const QString &tag, int a_track, int b_track, GenTime in, GenTime out, const QDomElement &xml)
 {
-    if (in >= out) return false;
+    if (in >= out) {
+        return false;
+    }
     double fps = m_tractor->get_fps();
     QMap<QString, QString> args = getTransitionParamsFromXml(xml);
     QScopedPointer<Mlt::Field> field(m_tractor->field());
 
     Mlt::Transition transition(*m_tractor->profile(), tag.toUtf8().constData());
-    if (!transition.is_valid()) return false;
-    if (out != GenTime())
+    if (!transition.is_valid()) {
+        return false;
+    }
+    if (out != GenTime()) {
         transition.set_in_and_out((int) in.frames(fps), (int) out.frames(fps) - 1);
+    }
 
     QMap<QString, QString>::Iterator it;
     QString key;
-    if (xml.attribute(QStringLiteral("automatic")) == QLatin1String("1")) transition.set("automatic", 1);
-    ////qDebug() << " ------  ADDING TRANSITION PARAMs: " << args.count();
-    if (xml.hasAttribute(QStringLiteral("id")))
+    if (xml.attribute(QStringLiteral("automatic")) == QLatin1String("1")) {
+        transition.set("automatic", 1);
+    }
+    ////qCDebug(KDENLIVE_LOG) << " ------  ADDING TRANSITION PARAMs: " << args.count();
+    if (xml.hasAttribute(QStringLiteral("id"))) {
         transition.set("kdenlive_id", xml.attribute(QStringLiteral("id")).toUtf8().constData());
-    if (xml.hasAttribute(QStringLiteral("force_track")))
+    }
+    if (xml.hasAttribute(QStringLiteral("force_track"))) {
         transition.set("force_track", xml.attribute(QStringLiteral("force_track")).toInt());
+    }
 
     for (it = args.begin(); it != args.end(); ++it) {
         key = it.key();
-        if (!it.value().isEmpty())
+        if (!it.value().isEmpty()) {
             transition.set(key.toUtf8().constData(), it.value().toUtf8().constData());
-        ////qDebug() << " ------  ADDING TRANS PARAM: " << key << ": " << it.value();
+        }
+        ////qCDebug(KDENLIVE_LOG) << " ------  ADDING TRANS PARAM: " << key << ": " << it.value();
     }
     // attach transition
     m_tractor->lock();
@@ -63,13 +72,13 @@ bool TransitionHandler::addTransition(QString tag, int a_track, int b_track, Gen
     return true;
 }
 
-void TransitionHandler::initTransition(QDomElement xml)
+void TransitionHandler::initTransition(const QDomElement &xml)
 {
     QMap<QString, QString> params = getTransitionParamsFromXml(xml);
     QMapIterator<QString, QString> i(params);
     while (i.hasNext()) {
         i.next();
-        EffectsList::setParameter(xml, i.key(),i.value());
+        EffectsList::setParameter(xml, i.key(), i.value());
     }
 }
 
@@ -95,7 +104,7 @@ QMap<QString, QString> TransitionHandler::getTransitionParamsFromXml(const QDomE
                 }
                 QStringList lumas = MainWindow::m_lumaFiles.value(lumaFolder);
                 bool found = false;
-                foreach(const QString &luma, lumas) {
+                foreach (const QString &luma, lumas) {
                     if (QUrl::fromLocalFile(luma).fileName() == defaultValue) {
                         map[name] = luma;
                         found = true;
@@ -112,9 +121,9 @@ QMap<QString, QString> TransitionHandler::getTransitionParamsFromXml(const QDomE
                 }
             } else {
                 if (defaultValue.contains(QLatin1Char('%'))) {
-                     ProfileInfo pInfo;
-                     pInfo.profileSize = QSize(m_tractor->profile()->width(), m_tractor->profile()->height());
-                     pInfo.profileFps = m_tractor->profile()->fps();
+                    ProfileInfo pInfo;
+                    pInfo.profileSize = QSize(m_tractor->profile()->width(), m_tractor->profile()->height());
+                    pInfo.profileFps = m_tractor->profile()->fps();
                     defaultValue = EffectsController::getStringRectEval(pInfo, defaultValue);
                 }
                 map[name] = defaultValue;
@@ -122,13 +131,13 @@ QMap<QString, QString> TransitionHandler::getTransitionParamsFromXml(const QDomE
         }
         double factor = e.attribute(QStringLiteral("factor"), QStringLiteral("1")).toDouble();
         double offset = e.attribute(QStringLiteral("offset"), QStringLiteral("0")).toDouble();
-        if (factor!= 1 || offset != 0) {
+        if (factor != 1 || offset != 0) {
             if (e.attribute(QStringLiteral("type")) == QLatin1String("simplekeyframe")) {
-                QStringList values = map.value(name).split(';', QString::SkipEmptyParts);
+                QStringList values = map.value(name).split(QLatin1Char(';'), QString::SkipEmptyParts);
                 for (int j = 0; j < values.count(); ++j) {
                     QString pos = values.at(j).section(QLatin1Char('='), 0, 0);
                     double val = (values.at(j).section(QLatin1Char('='), 1, 1).toDouble() - offset) / factor;
-                    values[j] = pos + '=' + locale.toString(val);
+                    values[j] = pos + QLatin1Char('=') + locale.toString(val);
                 }
                 map[name] = values.join(QLatin1Char(';'));
             } else if (e.attribute(QStringLiteral("type")) != QLatin1String("addedgeometry")) {
@@ -136,22 +145,24 @@ QMap<QString, QString> TransitionHandler::getTransitionParamsFromXml(const QDomE
                 //map[name]=map[name].replace(".",","); //FIXME how to solve locale conversion of . ,
             }
         }
-        if (e.attribute(QStringLiteral("namedesc")).contains(';')) {
+        if (e.attribute(QStringLiteral("namedesc")).contains(QLatin1Char(';'))) {
             //TODO: Deprecated, does not seem used anywhere...
             QString format = e.attribute(QStringLiteral("format"));
             QStringList separators = format.split(QStringLiteral("%d"), QString::SkipEmptyParts);
-            QStringList values = map.value(name).split(QRegExp("[,:;x]"));
+            QStringList values = map.value(name).split(QRegExp(QStringLiteral("[,:;x]")));
             QString neu;
             QTextStream txtNeu(&neu);
-            if (values.size() > 0)
+            if (!values.isEmpty()) {
                 txtNeu << (int)values[0].toDouble();
-            int i = 0;
-            for (i = 0; i < separators.size() && i + 1 < values.size(); ++i) {
-                txtNeu << separators[i];
-                txtNeu << (int)(values[i+1].toDouble());
             }
-            if (i < separators.size())
-                txtNeu << separators[i];
+            int j = 0;
+            for (j = 0; j < separators.size() && j + 1 < values.size(); ++j) {
+                txtNeu << separators[j];
+                txtNeu << (int)(values[j + 1].toDouble());
+            }
+            if (j < separators.size()) {
+                txtNeu << separators[j];
+            }
             map[name] = neu;
         }
 
@@ -172,12 +183,12 @@ void TransitionHandler::plantTransition(Mlt::Field *field, Mlt::Transition &tr,
     mlt_service nextservice = mlt_service_get_producer(field->get_service());
     mlt_properties properties = MLT_SERVICE_PROPERTIES(nextservice);
     QString resource = mlt_properties_get(properties, "mlt_service");
-    QList <Mlt::Transition *> trList;
+    QList<Mlt::Transition *> trList;
     mlt_properties insertproperties = tr.get_properties();
     QString insertresource = mlt_properties_get(insertproperties, "mlt_service");
     bool isMixTransition = insertresource == QLatin1String("mix");
 
-    mlt_service_type mlt_type = mlt_service_identify( nextservice );
+    mlt_service_type mlt_type = mlt_service_identify(nextservice);
     while (mlt_type == transition_type) {
         Mlt::Transition transition((mlt_transition) nextservice);
         nextservice = mlt_service_producer(nextservice);
@@ -193,18 +204,20 @@ void TransitionHandler::plantTransition(Mlt::Field *field, Mlt::Transition &tr,
             trList.append(cp);
             field->disconnect_service(transition);
         }
-        //else qDebug() << "// FOUND TRANS OK, "<<resource<< ", A_: " << aTrack << ", B_ "<<bTrack;
+        //else qCDebug(KDENLIVE_LOG) << "// FOUND TRANS OK, "<<resource<< ", A_: " << aTrack << ", B_ "<<bTrack;
 
-        if (nextservice == NULL) break;
+        if (nextservice == nullptr) {
+            break;
+        }
         properties = MLT_SERVICE_PROPERTIES(nextservice);
-        mlt_type = mlt_service_identify( nextservice );
+        mlt_type = mlt_service_identify(nextservice);
         resource = mlt_properties_get(properties, "mlt_service");
     }
     field->plant_transition(tr, a_track, b_track);
 
     // re-add upper transitions
     for (int i = trList.count() - 1; i >= 0; --i) {
-        ////qDebug()<< "REPLANT ON TK: "<<trList.at(i)->get_a_track()<<", "<<trList.at(i)->get_b_track();
+        ////qCDebug(KDENLIVE_LOG)<< "REPLANT ON TK: "<<trList.at(i)->get_a_track()<<", "<<trList.at(i)->get_b_track();
         field->plant_transition(*trList.at(i), trList.at(i)->get_a_track(), trList.at(i)->get_b_track());
     }
     qDeleteAll(trList);
@@ -214,28 +227,29 @@ void TransitionHandler::cloneProperties(Mlt::Properties &dest, Mlt::Properties &
 {
     int count = source.count();
     int i = 0;
-    for ( i = 0; i < count; i ++ )
-    {
+    for (i = 0; i < count; i ++) {
         char *value = source.get(i);
-        if ( value != NULL )
-        {
-            char *name = source.get_name( i );
-            if (name != NULL && name[0] != '_') dest.set(name, value);
+        if (value != nullptr) {
+            char *name = source.get_name(i);
+            if (name != nullptr && name[0] != QLatin1Char('_')) {
+                dest.set(name, value);
+            }
         }
     }
 }
 
-void TransitionHandler::updateTransition(QString oldTag, QString tag, int a_track, int b_track, GenTime in, GenTime out, QDomElement xml, bool force)
+void TransitionHandler::updateTransition(const QString &oldTag, const QString &tag, int a_track, int b_track, GenTime in, GenTime out, const QDomElement &xml, bool force)
 {
-    if (oldTag == tag && !force) updateTransitionParams(tag, a_track, b_track, in, out, xml);
-    else {
-        ////qDebug()<<"// DELETING TRANS: "<<a_track<<"-"<<b_track;
+    if (oldTag == tag && !force) {
+        updateTransitionParams(tag, a_track, b_track, in, out, xml);
+    } else {
+        ////qCDebug(KDENLIVE_LOG)<<"// DELETING TRANS: "<<a_track<<"-"<<b_track;
         deleteTransition(oldTag, a_track, b_track, in, out, xml, false);
         addTransition(tag, a_track, b_track, in, out, xml);
     }
 }
 
-void TransitionHandler::updateTransitionParams(QString type, int a_track, int b_track, GenTime in, GenTime out, QDomElement xml)
+void TransitionHandler::updateTransitionParams(const QString &type, int a_track, int b_track, GenTime in, GenTime out, const QDomElement &xml)
 {
     QScopedPointer<Mlt::Field> field(m_tractor->field());
     field->lock();
@@ -246,7 +260,7 @@ void TransitionHandler::updateTransitionParams(QString type, int a_track, int b_
     int in_pos = (int) in.frames(fps);
     int out_pos = (int) out.frames(fps) - 1;
 
-    mlt_service_type mlt_type = mlt_service_identify( nextservice );
+    mlt_service_type mlt_type = mlt_service_identify(nextservice);
     while (mlt_type == transition_type) {
         mlt_transition tr = (mlt_transition) nextservice;
         int currentTrack = mlt_transition_get_b_track(tr);
@@ -254,7 +268,7 @@ void TransitionHandler::updateTransitionParams(QString type, int a_track, int b_
         int currentIn = (int) mlt_transition_get_in(tr);
         int currentOut = (int) mlt_transition_get_out(tr);
 
-        // //qDebug()<<"Looking for transition : " << currentIn <<'x'<<currentOut<< ", OLD oNE: "<<in_pos<<'x'<<out_pos;
+        // //qCDebug(KDENLIVE_LOG)<<"Looking for transition : " << currentIn <<'x'<<currentOut<< ", OLD oNE: "<<in_pos<<'x'<<out_pos;
         if (resource == type && b_track == currentTrack && currentIn == in_pos && currentOut == out_pos) {
             QMap<QString, QString> map = getTransitionParamsFromXml(xml);
             QMap<QString, QString>::Iterator it;
@@ -286,15 +300,17 @@ void TransitionHandler::updateTransitionParams(QString type, int a_track, int b_
             for (it = map.begin(); it != map.end(); ++it) {
                 key = it.key();
                 mlt_properties_set(transproperties, key.toUtf8().constData(), it.value().toUtf8().constData());
-                //qDebug() << " ------  UPDATING TRANS PARAM: " << key.toUtf8().constData() << ": " << it.value().toUtf8().constData();
+                //qCDebug(KDENLIVE_LOG) << " ------  UPDATING TRANS PARAM: " << key.toUtf8().constData() << ": " << it.value().toUtf8().constData();
                 //filter->set("kdenlive_id", id);
             }
             break;
         }
         nextservice = mlt_service_producer(nextservice);
-        if (nextservice == NULL) break;
+        if (nextservice == nullptr) {
+            break;
+        }
         properties = MLT_SERVICE_PROPERTIES(nextservice);
-        mlt_type = mlt_service_identify( nextservice );
+        mlt_type = mlt_service_identify(nextservice);
         resource = mlt_properties_get(properties, "mlt_service");
     }
     field->unlock();
@@ -302,8 +318,7 @@ void TransitionHandler::updateTransitionParams(QString type, int a_track, int b_
     //if (m_isBlocked == 0) m_mltConsumer->set("refresh", 1);
 }
 
-
-bool TransitionHandler::deleteTransition(QString tag, int /*a_track*/, int b_track, GenTime in, GenTime out, QDomElement /*xml*/, bool /*do_refresh*/)
+bool TransitionHandler::deleteTransition(const QString &tag, int /*a_track*/, int b_track, GenTime in, GenTime out, const QDomElement &/*xml*/, bool /*do_refresh*/)
 {
     QScopedPointer<Mlt::Field> field(m_tractor->field());
     field->lock();
@@ -313,15 +328,15 @@ bool TransitionHandler::deleteTransition(QString tag, int /*a_track*/, int b_tra
     double fps = m_tractor->get_fps();
     const int old_pos = (int)((in + out).frames(fps) / 2);
     bool found = false;
-    ////qDebug() << " del trans pos: " << in.frames(25) << '-' << out.frames(25);
+    ////qCDebug(KDENLIVE_LOG) << " del trans pos: " << in.frames(25) << '-' << out.frames(25);
 
-    mlt_service_type mlt_type = mlt_service_identify( nextservice );
+    mlt_service_type mlt_type = mlt_service_identify(nextservice);
     while (mlt_type == transition_type) {
         mlt_transition tr = (mlt_transition) nextservice;
         int currentTrack = mlt_transition_get_b_track(tr);
         int currentIn = (int) mlt_transition_get_in(tr);
         int currentOut = (int) mlt_transition_get_out(tr);
-        ////qDebug() << "// FOUND EXISTING TRANS, IN: " << currentIn << ", OUT: " << currentOut << ", TRACK: " << currentTrack;
+        ////qCDebug(KDENLIVE_LOG) << "// FOUND EXISTING TRANS, IN: " << currentIn << ", OUT: " << currentOut << ", TRACK: " << currentTrack;
 
         if (resource == tag && b_track == currentTrack && currentIn <= old_pos && currentOut >= old_pos) {
             found = true;
@@ -329,9 +344,11 @@ bool TransitionHandler::deleteTransition(QString tag, int /*a_track*/, int b_tra
             break;
         }
         nextservice = mlt_service_producer(nextservice);
-        if (nextservice == NULL) break;
+        if (nextservice == nullptr) {
+            break;
+        }
         properties = MLT_SERVICE_PROPERTIES(nextservice);
-        mlt_type = mlt_service_identify( nextservice );
+        mlt_type = mlt_service_identify(nextservice);
         resource = mlt_properties_get(properties, "mlt_service");
     }
     field->unlock();
@@ -344,25 +361,29 @@ void TransitionHandler::deleteTrackTransitions(int ix)
 {
     QScopedPointer<Mlt::Field> field(m_tractor->field());
     mlt_service nextservice = mlt_service_get_producer(field->get_service());
-    mlt_service_type type = mlt_service_identify( nextservice );
+    mlt_service_type type = mlt_service_identify(nextservice);
     while (type == transition_type) {
-	Mlt::Transition transition((mlt_transition) nextservice);
+        Mlt::Transition transition((mlt_transition) nextservice);
         nextservice = mlt_service_producer(nextservice);
         int currentTrack = transition.get_b_track();
         if (ix == currentTrack) {
             field->disconnect_service(transition);
         }
-        if (nextservice == NULL) break;
-        type = mlt_service_identify(nextservice );
+        if (nextservice == nullptr) {
+            break;
+        }
+        type = mlt_service_identify(nextservice);
     }
 }
 
-bool TransitionHandler::moveTransition(QString type, int startTrack, int newTrack, int newTransitionTrack, GenTime oldIn, GenTime oldOut, GenTime newIn, GenTime newOut)
+bool TransitionHandler::moveTransition(const QString &type, int startTrack, int newTrack, int newTransitionTrack, GenTime oldIn, GenTime oldOut, GenTime newIn, GenTime newOut)
 {
     double fps = m_tractor->get_fps();
     int new_in = (int)newIn.frames(fps);
     int new_out = (int)newOut.frames(fps) - 1;
-    if (new_in >= new_out) return false;
+    if (new_in >= new_out) {
+        return false;
+    }
     int old_in = (int)oldIn.frames(fps);
     int old_out = (int)oldOut.frames(fps) - 1;
 
@@ -373,7 +394,7 @@ bool TransitionHandler::moveTransition(QString type, int startTrack, int newTrac
     QString resource = mlt_properties_get(properties, "mlt_service");
     int old_pos = (int)(old_in + old_out) / 2;
     bool found = false;
-    mlt_service_type mlt_type = mlt_service_identify( nextservice );
+    mlt_service_type mlt_type = mlt_service_identify(nextservice);
     while (mlt_type == transition_type) {
         Mlt::Transition transition((mlt_transition) nextservice);
         nextservice = mlt_service_producer(nextservice);
@@ -392,12 +413,16 @@ bool TransitionHandler::moveTransition(QString type, int startTrack, int newTrac
                 new_transition.set_in_and_out(new_in, new_out);
                 field->disconnect_service(transition);
                 plantTransition(field.data(), new_transition, newTransitionTrack, newTrack);
-            } else transition.set_in_and_out(new_in, new_out);
+            } else {
+                transition.set_in_and_out(new_in, new_out);
+            }
+            break;
+        }
+        if (nextservice == nullptr) {
             break;
         }
-        if (nextservice == NULL) break;
         properties = MLT_SERVICE_PROPERTIES(nextservice);
-        mlt_type = mlt_service_identify( nextservice );
+        mlt_type = mlt_service_identify(nextservice);
         resource = mlt_properties_get(properties, "mlt_service");
     }
     field->unlock();
@@ -415,11 +440,10 @@ Mlt::Transition *TransitionHandler::getTransition(const QString &name, int b_tra
                 if (a_track == -1 || t.get_a_track() == a_track) {
                     int internal = t.get_int("internal_added");
                     if (internal == 0) {
-                      if (!internalTransition) {
-                          return new Mlt::Transition(t);
-                      }
-                    }
-                    else if (internalTransition) {
+                        if (!internalTransition) {
+                            return new Mlt::Transition(t);
+                        }
+                    } else if (internalTransition) {
                         return new Mlt::Transition(t);
                     }
                 }
@@ -427,10 +451,10 @@ Mlt::Transition *TransitionHandler::getTransition(const QString &name, int b_tra
         }
         service.reset(service->producer());
     }
-    return 0;
+    return nullptr;
 }
 
-Mlt::Transition *TransitionHandler::getTrackTransition(const QStringList names, int b_track, int a_track) const
+Mlt::Transition *TransitionHandler::getTrackTransition(const QStringList &names, int b_track, int a_track) const
 {
     QScopedPointer<Mlt::Service> service(m_tractor->field());
     while (service && service->is_valid()) {
@@ -438,39 +462,46 @@ Mlt::Transition *TransitionHandler::getTrackTransition(const QStringList names,
             Mlt::Transition t((mlt_transition) service->get_service());
             int internal = t.get_int("internal_added");
             if (internal >= 200) {
-                QString service = t.get("mlt_service");
-                if (names.contains(service) && t.get_b_track() == b_track && (a_track == -1 || t.get_a_track() == a_track)) {
+                if (names.contains(t.get("mlt_service")) && t.get_b_track() == b_track && (a_track == -1 || t.get_a_track() == a_track)) {
                     return new Mlt::Transition(t);
                 }
             }
         }
         service.reset(service->producer());
     }
-    return 0;
+    return nullptr;
 }
 
-void TransitionHandler::duplicateTransitionOnPlaylist(int in, int out, QString tag, QDomElement xml, int a_track, int b_track, Mlt::Field *field)
+void TransitionHandler::duplicateTransitionOnPlaylist(int in, int out, const QString &tag, const QDomElement &xml, int a_track, int b_track, Mlt::Field *field)
 {
     QMap<QString, QString> args = getTransitionParamsFromXml(xml);
     Mlt::Transition transition(*m_tractor->profile(), tag.toUtf8().constData());
-    if (!transition.is_valid()) return;
-    if (out != 0)
+    if (!transition.is_valid()) {
+        return;
+    }
+    if (out != 0) {
         transition.set_in_and_out(in, out);
+    }
 
     QMap<QString, QString>::Iterator it;
     QString key;
-    if (xml.attribute(QStringLiteral("automatic")) == QLatin1String("1")) transition.set("automatic", 1);
-    ////qDebug() << " ------  ADDING TRANSITION PARAMs: " << args.count();
-    if (xml.hasAttribute(QStringLiteral("id")))
+    if (xml.attribute(QStringLiteral("automatic")) == QLatin1String("1")) {
+        transition.set("automatic", 1);
+    }
+    ////qCDebug(KDENLIVE_LOG) << " ------  ADDING TRANSITION PARAMs: " << args.count();
+    if (xml.hasAttribute(QStringLiteral("id"))) {
         transition.set("kdenlive_id", xml.attribute(QStringLiteral("id")).toUtf8().constData());
-    if (xml.hasAttribute(QStringLiteral("force_track")))
+    }
+    if (xml.hasAttribute(QStringLiteral("force_track"))) {
         transition.set("force_track", xml.attribute(QStringLiteral("force_track")).toInt());
+    }
 
     for (it = args.begin(); it != args.end(); ++it) {
         key = it.key();
-        if (!it.value().isEmpty())
+        if (!it.value().isEmpty()) {
             transition.set(key.toUtf8().constData(), it.value().toUtf8().constData());
-        ////qDebug() << " ------  ADDING TRANS PARAM: " << key << ": " << it.value();
+        }
+        ////qCDebug(KDENLIVE_LOG) << " ------  ADDING TRANS PARAM: " << key << ": " << it.value();
     }
     // attach transition
     field->plant_transition(transition, a_track, b_track);
@@ -489,21 +520,21 @@ void TransitionHandler::enableMultiTrack(bool enable)
     field->lock();
     if (enable) {
         // disable track composition (frei0r.cairoblend)
-        QScopedPointer<Mlt::Field> field(m_tractor->field());
         mlt_service nextservice = mlt_service_get_producer(field->get_service());
-        mlt_service_type type = mlt_service_identify( nextservice );
+        mlt_service_type type = mlt_service_identify(nextservice);
         while (type == transition_type) {
             Mlt::Transition transition((mlt_transition) nextservice);
             nextservice = mlt_service_producer(nextservice);
             int added = transition.get_int("internal_added");
             if (added == 237) {
-                QString mlt_service = transition.get("mlt_service");
-                if (compositeService.contains(mlt_service) && transition.get_int("disable") == 0) {
+                if (compositeService.contains(transition.get("mlt_service")) && transition.get_int("disable") == 0) {
                     transition.set("disable", 1);
                     transition.set("split_disable", 1);
                 }
             }
-            if (nextservice == NULL) break;
+            if (nextservice == nullptr) {
+                break;
+            }
             type = mlt_service_identify(nextservice);
         }
         for (int i = 1, screen = 0; i < tracks && screen < 4; ++i) {
@@ -540,9 +571,8 @@ void TransitionHandler::enableMultiTrack(bool enable)
             }
         }
     } else {
-        QScopedPointer<Mlt::Field> field(m_tractor->field());
         mlt_service nextservice = mlt_service_get_producer(field->get_service());
-        mlt_service_type type = mlt_service_identify( nextservice );
+        mlt_service_type type = mlt_service_identify(nextservice);
         while (type == transition_type) {
             Mlt::Transition transition((mlt_transition) nextservice);
             nextservice = mlt_service_producer(nextservice);
@@ -551,13 +581,14 @@ void TransitionHandler::enableMultiTrack(bool enable)
                 field->disconnect_service(transition);
             } else if (added == 237) {
                 // re-enable track compositing
-                QString mlt_service = transition.get("mlt_service");
-                if (compositeService.contains(mlt_service) && transition.get_int("split_disable") == 1) {
+                if (compositeService.contains(transition.get("mlt_service")) && transition.get_int("split_disable") == 1) {
                     transition.set("disable", 0);
-                    transition.set("split_disable", (char*) NULL);
+                    transition.set("split_disable", (char *) nullptr);
                 }
             }
-            if (nextservice == NULL) break;
+            if (nextservice == nullptr) {
+                break;
+            }
             type = mlt_service_identify(nextservice);
         }
     }
@@ -565,11 +596,12 @@ void TransitionHandler::enableMultiTrack(bool enable)
     emit refresh();
 }
 
-// static 
+// static
 const QString TransitionHandler::compositeTransition()
 {
-    if (KdenliveSettings::gpu_accel())
+    if (KdenliveSettings::gpu_accel()) {
         return QStringLiteral("movit.overlay");
+    }
     if (MainWindow::transitions.hasTransition(QStringLiteral("qtblend"))) {
         return QStringLiteral("qtblend");
     }
@@ -579,10 +611,10 @@ const QString TransitionHandler::compositeTransition()
     return QStringLiteral("composite");
 }
 
-void TransitionHandler::rebuildTransitions(int mode, QList <int> videoTracks, int maxTrack)
+void TransitionHandler::rebuildTransitions(int mode, const QList<int> &videoTracks, int maxTrack)
 {
     QStringList compositeService { QStringLiteral("qtblend"), QStringLiteral("composite"), QStringLiteral("frei0r.cairoblend"),  QStringLiteral("movit.overlay") };
-    QList <int> disabled;
+    QList<int> disabled;
     QScopedPointer<Mlt::Service> service(m_tractor->field());
     Mlt::Field *field = m_tractor->field();
     field->lock();
@@ -592,13 +624,12 @@ void TransitionHandler::rebuildTransitions(int mode, QList <int> videoTracks, in
             Mlt::Transition t((mlt_transition) service->get_service());
             int internal = t.get_int("internal_added");
             if (internal == 237) {
-                QString service = t.get("mlt_service");
-                if (service == QLatin1String("mix")) {
+                QString serviceName = t.get("mlt_service");
+                if (serviceName == QLatin1String("mix")) {
                     field->disconnect_service(t);
-                }
-                else if (compositeService.contains(service)) {
+                } else if (compositeService.contains(serviceName)) {
                     if (mode < 0) {
-                        mode = service == QLatin1String("composite") ? 1 : 2;
+                        mode = serviceName == QLatin1String("composite") ? 1 : 2;
                     }
                     field->disconnect_service(t);
                 }
@@ -628,11 +659,11 @@ void TransitionHandler::rebuildTransitions(int mode, QList <int> videoTracks, in
     QString compositeGeometry;
     if (mode == 1) {
         composite = QStringLiteral("composite");
-        compositeGeometry = QString("0=0/0:%1x%2").arg(m_tractor->profile()->width()).arg(m_tractor->profile()->height());
+        compositeGeometry = QStringLiteral("0=0/0:%1x%2").arg(m_tractor->profile()->width()).arg(m_tractor->profile()->height());
     } else {
         composite = compositeTransition();
     }
-    foreach(int track,  videoTracks) {
+    foreach (int track,  videoTracks) {
         Mlt::Transition transition(*m_tractor->profile(), composite.toUtf8().constData());
         transition.set("always_active", 1);
         transition.set("a_track", 0);
